#pragma rtGlobals=3		// Use modern global access method and strict wave access.
#include <PieChart>

//	Release history: v1.0 Aug 02, 2018

Constant Version=1.0

Macro RO2_Fate_Estimator_Init()

	silent 1

	newdatafolder/O/S root:RO2Fate
	Variable/G root:RO2Fate:OHRVOC=1
	Variable/G root:RO2Fate:RO2=5e8
	Variable/G root:RO2Fate:OH=1.5e6
	Variable/G root:RO2Fate:HO2=1.5e8
	Variable/G root:RO2Fate:NO=7e7
	Variable/G root:RO2Fate:NO2=2e8
	Variable/G root:RO2Fate:kHO2=1.5e-11
	Variable/G root:RO2Fate:kNO=9e-12
	Variable/G root:RO2Fate:kNO2=0
	Variable/G root:RO2Fate:kRO2=1e-13
	Variable/G root:RO2Fate:kOH=1e-10
	Variable/G root:RO2Fate:kiso=0.1
	make/T/O/N=2 InputOptions={"Organic OH reactivity","RO\B2\M concentration"}

End Macro

Menu "General_RO2_Fate_Estimator"

	"Open_Main_Panel"
	
End Menu

Function Open_Main_Panel()

	silent 1
	
	if (stringmatch(WinList("RO2_Fate_Estimator",";","WIN:64"),"RO2_Fate_Estimator;"))
		DoWindow/F RO2_Fate_Estimator
	else
		execute/Q "RO2_Fate_Estimator_Init()"
		execute/Q "RO2_Fate_Estimator()"
	endif

End Function

Window RO2_Fate_Estimator() : Panel
	PauseUpdate; Silent 1		// building window...
	NewPanel /W=(104,54,584,470)
	SetDrawLayer UserBack
	SetDrawEnv fsize= 24,fstyle= 1
	
	String VerStr
	sprintf VerStr,"%.1f",Version
	DrawText 12,43,"RO\\B2\\M Fate Estimator v"+VerStr
	
	DrawLine 1,186,604,186
	SetDrawEnv fname= "Calibri Light",fsize= 14
	DrawText 107,56,"Zhe Peng and Jose-Luis Jimenez"
	DrawPICT 405,6,0.63,0.63,ProcGlobal#CULogo
	SetDrawEnv fstyle= 1
	DrawText 10,82,"Select an input option"
	SetDrawEnv fname= "NSimSun",fsize= 200
	DrawText 56,418,"{"
	SetDrawEnv fstyle= 1
	DrawText 289,214,"\\JRRelative contribution to RO\\B2\\M fate"
	SetDrawEnv fstyle= 1
	DrawText 10,152,"Enter species concentrations (molecules cm\\S-3\\M)"
	DrawPICT 405,85,0.73,0.73,ProcGlobal#NSFLogo
	SetDrawEnv fsize= 22,fstyle= 1
	DrawText 40,332,"RO\\B2"
	SetDrawEnv dash= 3
	DrawLine 145,250,543,250
	SetDrawEnv dash= 3
	DrawLine 145,281,545,281
	SetDrawEnv dash= 3
	DrawLine 145,347,546,347
	SetDrawEnv dash= 3
	DrawLine 145,378,546,378
	DrawText 14,370,"\\JCConcentration\r(molecules cm\\S-3\\M)"
	SetDrawEnv dash= 3
	DrawLine 145,315,546,315
	SetDrawEnv fstyle= 1
	DrawText 145,212,"k (cm\\S3\\M molecule\\S-1\\M s\\S-1\\M)"
	Button button1,pos={313.00,42.00},size={60.00,25.00},proc=RO2Fate_ButtonProc_1,title="Readme"
	Button button1,fSize=14,fStyle=0,fColor=(65280,49152,16384)
	ListBox list0,pos={11.00,86.00},size={140.00,42.00},proc=RO2Fate_ListBoxProc
	ListBox list0,listWave=root:RO2Fate:InputOptions,mode= 2,selRow= 0,editStyle= 2
	ListBox list0,widths={100}
	SetVariable setvar1,pos={162.00,91.00},size={191.00,24.00},bodyWidth=50,proc=RO2Fate_SetVarProc,title="Organic OH reactivity (s\\S-1\\M)"
	SetVariable setvar1,limits={0,1000,1},value= root:RO2Fate:OHRVOC
	SetVariable setvar2,pos={11.00,158.00},size={74.00,20.00},bodyWidth=50,disable=2,proc=RO2Fate_SetVarProc_1,title="RO\\B2\\M"
	SetVariable setvar2,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:RO2
	SetVariable setvar3,pos={106.00,158.00},size={72.00,18.00},bodyWidth=50,proc=RO2Fate_SetVarProc_2,title="OH"
	SetVariable setvar3,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:OH
	SetVariable setvar4,pos={301.00,157.00},size={72.00,18.00},bodyWidth=50,proc=RO2Fate_SetVarProc_4,title="NO"
	SetVariable setvar4,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:NO
	SetVariable setvar5,pos={200.00,157.00},size={76.00,20.00},bodyWidth=50,proc=RO2Fate_SetVarProc_3,title="HO\\B2\\M"
	SetVariable setvar5,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:HO2
	Button button5,pos={284.00,137.00},size={15.00,15.00},proc=RO2Fate_ButtonProc_3,title="?"
	Button button5,fColor=(65280,49152,16384)
	Button button06,pos={363.00,96.00},size={15.00,15.00},proc=RO2Fate_ButtonProc_2,title="?"
	Button button06,fColor=(65280,49152,16384)
	SetVariable setvar6,pos={149.00,225.00},size={85.00,20.00},bodyWidth=50,proc=RO2Fate_SetVarProc_5,title="\\f01+HO\\B2"
	SetVariable setvar6,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:kHO2
	SetVariable setvar7,pos={149.00,257.00},size={80.00,18.00},bodyWidth=50,proc=RO2Fate_SetVarProc_6,title="\\f01+NO"
	SetVariable setvar7,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:kNO
	SetVariable setvar8,pos={149.00,322.00},size={84.00,20.00},bodyWidth=50,proc=RO2Fate_SetVarProc_7,title="\\f01+RO\\B2"
	SetVariable setvar8,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:kRO2
	SetVariable setvar9,pos={149.00,354.00},size={80.00,18.00},bodyWidth=50,proc=RO2Fate_SetVarProc_8,title="\\f01+OH"
	SetVariable setvar9,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:kOH
	SetVariable setvar10,pos={149.00,384.00},size={176.00,24.00},bodyWidth=50,proc=RO2Fate_SetVarProc_9,title="\\f01isomerization (k in s\\S-1\\M)"
	SetVariable setvar10,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:kiso
	ValDisplay valdisp0,pos={375.00,227.00},size={50.00,17.00},fSize=12
	ValDisplay valdisp0,format="%.1f%%",fStyle=1,valueBackColor=(52428,52428,52428)
	ValDisplay valdisp0,limits={0,0,0},barmisc={0,1000}
	ValDisplay valdisp0,value= #"root:RO2Fate:RO2Fate_RelCont[0]"
	Button button0,pos={26.00,229.00},size={65.00,44.00},proc=RO2Fate_ButtonProc,title="Calculate\rRO\\B2\\M Fate"
	Button button0,fSize=14,fColor=(65280,49152,16384)
	Button button6,pos={244.00,227.00},size={15.00,15.00},proc=RO2Fate_ButtonProc_7,title="?"
	Button button6,fColor=(65280,49152,16384)
	Button button7,pos={238.00,258.00},size={15.00,15.00},proc=RO2Fate_ButtonProc_8,title="?"
	Button button7,fColor=(65280,49152,16384)
	Button button8,pos={243.00,324.00},size={15.00,15.00},proc=RO2Fate_ButtonProc_9,title="?"
	Button button8,fColor=(65280,49152,16384)
	Button button9,pos={238.00,355.00},size={15.00,15.00},proc=RO2Fate_ButtonProc_10,title="?"
	Button button9,fColor=(65280,49152,16384)
	Button button10,pos={334.00,390.00},size={15.00,15.00},proc=RO2Fate_ButtonProc_11,title="?"
	Button button10,fColor=(65280,49152,16384)
	ValDisplay valdisp5,pos={33.00,380.00},size={58.00,17.00},fSize=12,format="%.1e"
	ValDisplay valdisp5,fStyle=1,valueBackColor=(52428,52428,52428)
	ValDisplay valdisp5,limits={0,0,0},barmisc={0,1000},value= #"root:RO2Fate:RO2"
	ValDisplay valdisp1,pos={375.00,257.00},size={50.00,17.00},fSize=12
	ValDisplay valdisp1,format="%.1f%%",fStyle=1,valueBackColor=(52428,52428,52428)
	ValDisplay valdisp1,limits={0,0,0},barmisc={0,1000}
	ValDisplay valdisp1,value= #"root:RO2Fate:RO2Fate_RelCont[1]"
	ValDisplay valdisp2,pos={375.00,324.00},size={50.00,17.00},fSize=12
	ValDisplay valdisp2,format="%.1f%%",fStyle=1,valueBackColor=(52428,52428,52428)
	ValDisplay valdisp2,limits={0,0,0},barmisc={0,1000}
	ValDisplay valdisp2,value= #"root:RO2Fate:RO2Fate_RelCont[2]"
	ValDisplay valdisp3,pos={375.00,354.00},size={50.00,17.00},fSize=12
	ValDisplay valdisp3,format="%.1f%%",fStyle=1,valueBackColor=(52428,52428,52428)
	ValDisplay valdisp3,limits={0,0,0},barmisc={0,1000}
	ValDisplay valdisp3,value= #"root:RO2Fate:RO2Fate_RelCont[3]"
	ValDisplay valdisp4,pos={375.00,389.00},size={50.00,17.00},fSize=12
	ValDisplay valdisp4,format="%.1f%%",fStyle=1,valueBackColor=(52428,52428,52428)
	ValDisplay valdisp4,limits={0,0,0},barmisc={0,1000}
	ValDisplay valdisp4,value= #"root:RO2Fate:RO2Fate_RelCont[4]"
	SetVariable setvar11,pos={149.00,289.00},size={85.00,20.00},bodyWidth=50,disable=2,proc=RO2Fate_SetVarProc_10,title="\\f01+NO\\B2"
	SetVariable setvar11,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:kNO2
	Button button2,pos={243.00,291.00},size={15.00,15.00},proc=RO2Fate_ButtonProc_12,title="?"
	Button button2,fColor=(65280,49152,16384)
	ValDisplay valdisp6,pos={375.00,291.00},size={50.00,17.00},fSize=12
	ValDisplay valdisp6,format="%.1f%%",fStyle=1,valueBackColor=(52428,52428,52428)
	ValDisplay valdisp6,limits={0,0,0},barmisc={0,1000}
	ValDisplay valdisp6,value= #"root:RO2Fate:RO2Fate_RelCont[5]"
	CheckBox check0,pos={182.00,68.00},size={68.00,17.00},proc=RO2Fate_CheckProc,title="Acyl RO\\B2\\M?"
	CheckBox check0,fSize=12,fStyle=1,value= 0
	SetVariable setvar0,pos={394.00,157.00},size={76.00,20.00},bodyWidth=50,proc=RO2Fate_SetVarProc_11,title="NO\\B2"
	SetVariable setvar0,format="%.1e",limits={0,1e+020,0},value= root:RO2Fate:NO2
EndMacro

// PNG: width= 136, height= 158
Picture CULogo
	ASCII85Begin
	M,6r;%14!\!!!!.8Ou6I!!!"T!!!"j#R18/!9l@-e,TIk!(fRE<-Xr#>mFUK`u"^b%QL^;MP@&B=Ki
	p";8g6*,`5'dfJOG'YpZfPg+XFTCb`A#@P"cR`Rm$t)NC[m/.`a9U*:dZUtu+WqqmgT>HW#eGI6_WD
	h%-1m`rJ9rV"L*o&bcG((_TR&$1Xm!!+Ab!^Qr+KKp(L"sFOGJ3eu!EcH87)Iaa-6]PD`.=(R&[[[G
	72>2fj<ImOR:e2F/g@D<R4T'Oh[d?8>n;-7nPY!5`]]Fkk,Eh!M2-_7q&]1K0-CQ1Ek-+Pgh/Sss*+
	`iPFQ29Ng[tLWFq[DEFNCqUQ't(**5-[m6?>puM[QH$`BQ""o[7+A-!29];+"lmUJ.XIQN"CT-c_#R
	L1Afi\O_ao=X4&PM/?,H_#r`;Nh[jC#jgH3X`!tA,UifY/R;YN6V3<:Yg(6[ITBuG3]MIpe)jAl12.
	BHKq&f58J+:%am-/lMMiGW8M>#0s(g2fj#)ZYP+mM.WKngSTaE);LaE^);KP_c;*p;aX6W@t3Kt(G;
	Y3fO8U^1[!l#iTX$i+<#ssg-a?u1;IdR/*Ij667lb]8b:OH'adZlt/FgWU?jRg36PK&tO5H$u46O?b
	U<2sV-InNNgqVL'.!qbbf-cbM6b>Rtq6YpNK-eHY0P)Dh(jDga*-bm6FHCfa4[ZRda)&AS!^C$/TCt
	j!\i8E$!]6EXs==f23/iW+rEoeS1f0;MR5m.l2$>%W,18O\W?BCRC;+HTa2(:fo'JG-uIK9Wr&4D%7
	Pc7E1Q]KE90rFGM6kua]6<32LArrt`UWa9[mu[l\\FQ$TVkqI2Tp!?irVH2eA*VR)"G/$uiX&N7EtE
	BR=`dVEo=lbaj3m.WLD5sGX&LQe-HXF8bYA`<eimcNki"&uIbV1FY?o3=a3on\XBW:pT=[FPOe/TH$
	gHU8q/-_S09^!5;U4-tr=c)(imI]0Ga":s@+i^YbYA]kDf8;h58%\P:Q<)dEchoj'+qB:OHe6'XB<'
	8_"mlAeJaVuI>HCkL\u)A<d)R+c.'@4Z"cWO-,rl8#T?)OAg[l[)@8EqL&YcW4\aX+1TLqie<g=!hn
	Wk5^J?\BQ*h(B4=ZIaA6-65,D9[3#)EK*c,gaBTn(f&6L+3k$rm`\^]FX9)LnRuJd,)-:rR*5clhTb
	WYc0N)FPS]BuNX0CS4keG0%dk_V1k,rV]IWD*"Mu\3]8^<2nPK9f<q^(&kkmMG]/^$1d0I,MWPP?/?
	'K%;>(^()b4I=FqAS1JM=k"7OfXo=aS3orF0cAfI9nRE&4]m2]HDG)cOhhtRG$nKN_U$Q;DRAgb[)U
	W;SqMQ:1;$_0uR.ZW/qo2fI6,jN(_f"NWfGl+]Jd=7-.]Qo^"d3"=sI88-3C+/U^0m>9'ebQhBPmok
	5rl4=##oZ2P-(Z6F`l]ER\CR^[p7'^C]V%P)ps0V,TLo"ue9D_$%A=k3J3aGD&RZ0(Wa]f3lnE2HB\
	;%m+=esHn,ID@8\Sn]l.-=3mdC"$V7k'dXMA@uaKs>=97DJR-P"Apg?c2EoQkpV98Z'>mUV3IqD>tJ
	=*I@R:Onk+QQWS-.BH[ic.:_`=W%NLkK.X>[sg2m&CG]O0CV,fMU#hU>C^/G[6\\8&&[ADa5HA!84c
	^B?sgGs)RLQ<mh[QB@Ud/7aTN:dC':Noi.h6E>+oAq9(_nbkqfUEi/&(8&g]Q(/QmX!)`JM@3+X.G"
	HcZ&6H`,&Z/Fr^4A"\\RU'An,*8S`TiK&COu2j$J=nRmW0-/na`GEn&jhWThP13o'JX^`+SM(9Bk`a
	iXDX9`=MAUJ5`R%ChGt'4,gADE@5S@DTZ)]Vn9GAk,Qn5G"X<C!?Z]$H!L[#OhgT<,Uu(niQ)Zd:95
	WufULo/H!]c,E#5^]2S&@pP3K"C;,Y:d-7uJ-7N6]A>[1?QB8DefV>)djf78+>#^X:j]fs59?[Vai8
	FFF;8LO;2+FD6p,(O]AX9T5AMZ?Yp6F:D1M,n!2%`TV'm#l&>RkcT**-<\']&i)7!@Ei=,7qAOls-"
	hVnAV+d/1J2],!^_!@V?Fb_p!M3,:bXdM#P8%T`gT"=CepK,SF]$PSI<]9eoDF-'B!>%'[g;6W5g4L
	JFDu:pk&3o5<5R=;f2MYR!N%W^/C<?Qc";-b>]Jl#2GCA6N,)O_G@gql4sDD(`n5*eac[6\+\T&o7'
	-H1OkUUEAl$02@W,M&_Eh/gsa\8eWaB&@0)VUF+4ti89J7'2Q6.e#&m8MkS*Z&s=oiT?*_ur$1bE3A
	hVk'9EHW<&#Y1$Q4@5X#N:^r!ra)QMn#hcQdTXjn4$pA??Mu*4;7Gefr/eOhKuV&g>8RITW[^La*N]
	HsJ"#Z>:CtGAiV*KZ(L'fr-PGmuBYu*7j-IBAENR@F7l+'Y^'_fOE;TKH.qmQo'8D5RnH9ESYA>A#i
	OlA7T4Yh1kTIp#m[,Ue,1EQOF6]f'T2#Nq"2$UiBuLEYo%6EHBB]S=FCX^@j?@Da-]_6I;QE(OZ%Tj
	i2+9V\&@YBK6LPei";eZ`KkA#XY2B,Xh`F+D-WR`+*..8rZ9%Q5'.88TcgqiCRAj,Z,qETK*@:,1Rf
	.&5D`fp+H:?ka'3ZEcq*h_PJ"L`Bk+:V$FlU%06YV&4D%7#Qt`I&->-#(kb-c!<s\Y7"@Q/";,#Qg'
	!OD8'paLd'WO@grVB*OiW/2dCsHZI!rA`F$VT'j0SJbd<ESgUud)KM$>DmL33].a$"-VMc(tee0*_:
	*[:LT^Q<$EW449Z#qp!X_?Z,8$KptfQ%[0i,2Bf$Ke1\O.1m\6_H;TPNAU)SPJ9)70.-A3LYj+)7`b
	uASHNq!*\$YeN`rT/A?++C)A/0r9hM2A5`SMe(Tpafc/F/;]m`SoT.ZX^L!m94RMc;XbVR7)M(!(uV
	15"ggti>IKJ96GX`Q99%:+_e>o;(6GKB[7`gYd:/[JiCC]oZ0Lhpc<;Pfn\W9EHDUQ?a7d&=3Po1_q
	S7YXkHZ&KTpnd_TJ.@a\HI#cEeCLkQK-s,(6p,YgN@^S\pWht6;fX<!5?cBV+&B$o;(cfmDT7M4D)h
	Xn_=a1gm#G:a16dqnrB^=-9DGBHm@HGm`aAB"4ZL:WmRFKX&8:>l-4pDH5JFPj00jkB/H'.F$Kgt[c
	`SWaM%Gk,;^!PWfQfctu8HW]-5L3?5dYMb5bZB)YU?V-acd`I6#Q1;MR+$$7i"Gg/oV0YtdNrUR2Xm
	L9OX`^U9d2ZErnrT#4?U:a!s?;'^VD/f*-6N/L5l!K,DUc!eL*[sh?2Ej^Z0D.5%ecm%=4Qtq(2m\&
	O_BNLON_BcLY-oYn&kuI"d3SnS-`?!$aZE%Sq,%kU"eRn]*^W+k.X2&"JhY%:i@,PMb`.e*21\k8*F
	#NH@>6NU.E]0+Ol2aWqA'WZj+:\*&N':P+Vq$qHY-DKPp(JKT&Uq%VEnnd:c:#!:IbrsXfUaD]Pk]t
	X^-7N<$3%C%(>YUcpi##4uO/tc]Sdi1FS.MhhiTB#j(:Z,IC;a`E6)<Ht"7agI\agOOYrA1s+DBHPn
	$$%#3kqDD;;]1khhP\Dp%c,`Po0o6Q94bd51^E-EN3Ni:"@a'QCWuR"ob_n>!9SU-eleQ"fJJP$:sY
	Ek^[e8]QW.S_TN^tHZ8Hb'KK0U8_#BqMD7Ru[h4JoPcIZpRS9g<uSp.t^L1[!!QQD@V^,[.MjQ>T<j
	o+2o4>%05V9CahFQu(TnbKm6\=/7Hcau+2nS(2#L>=aC#teo3mSRk3(EHs/*^43LUcE_`=]r4?HEN?
	^H^<;7CRK@'H\VQJ8#o<aLF'3l8XV,DZC7lBdS)"Lbo7u[/!INQ,>dbF[.0SfiDiCE*-.$c0kPsT43
	BrO5$2f=$2V+R.hdcM9iM?b(@OM4dTU+p^o1?u_%(<#@b=2@UXf'DTubf"+j"\PqaS0KAs,CD=NPQ-
	3>[BAe9r3$2G\n)8kabmDV_N\lkc\<EZZmM^)K,aO(Xt;B@fTMr09L8]@V^g*>!XWMf2\gK7t0(kFu
	XhM:ms5)GY,r@cM8hHN*2d/%YUr`"L]n.\Ta_/oVE_<Y^lG[]!<=17cqNW97\dVM)?:EC[>dfG;kuM
	ccHZ%BHSEkhk7-8-9l8S00[Y9nIjXY!CM[E^p(;S/$8<k#4EeMpZ.p#MeaHh)HLO;=>ib@Xj1SIAnH
	<HEbF+\76<GB)&-Q7V];<*P5e3$uQ*[?\>OsosaR!Zk4P;eV972KFCoT>Y?@1Qbs)%bH(Y7H=V*c3J
	Br9Qoqr#ar=b.E7Iu1XK$SU_D#kAdHu:aBU-Cua0s>XVnbK0Ag^)G_Vt^_khAq[F?_MF2JYnYUhT\;
	`?YoM`=*8;m;tC3:43UfjFuV"BE*nHq@J+`6qDZRNujK<c(e#oABJFt)d2um(rc/Os,Z"YGNH*`(Jh
	EoYeJAi^<l^n3n+,>[YHQHR3,Ju3f\\27Ip_lUiniD$(?WFH[D.PFV@L12uH$<-3X]9YSf.@Z"\JC4
	dn(;*K#0[[9eH@Ea0<*Kk%3"4\*1$\"%;ak)X9@p<d9ZG@\m.Pn'[9>i)fVmL:072Q&,@r=&<e2KqN
	p-6?ok8)kBSFE`B+d%>FB,]`I0PJ),I6!V#\:2H@'-[O05XI;!Mms"4cdipB/n(&SrK1'4@75kLO.Q
	$OHaUU=1p&jKM.qB29mIjtYJI#;:PL6@L3Ks%g'mf+8"MOR-48=']02uDNG.8)0ZEggh!\cbs&1OPI
	4bpgog&Zjkgk*nO;<[CZb;N(u@)GuKW\&t?>t=4p"t_m2DKWj(F.@lb>(6[[%3.nH!S[9*I/@ED^H2
	MkY+3>s-Vi[DPq^oA+Y=G7D-f=<T*F2k'^mMTpDO4d0'bOhD609CK)I2q@V5(KW60RZTtbTt$YNt;Q
	?6PC:g[eT)'bk?VBP5J"I+=eh"BeCOR$?JU36+(>q`H1j:Q\A2Sl0[#AH!$-=8F4O-7c<m@r0QE+"/
	<Q,j`p)M*5V`BEi"'YeG9#+?ZSH<YP56oT.9H;ZRDY+3@lM2Q)u[]4N_\jWZ2jY?.*RflE<-VKP?ep
	sV>K$.X,mttbcH#%f_[s1qBd,q.B'eMSYJiXVZBoj=Ai+;Y&q'tQGimjcX74`9'f^]t<L@5)TmPs'Z
	12p^UBmMm^YV3L%"Tq?hHJAs2O!BlHBU.:;BhU!fMncn-m]I#h^Y'e+%gpHj3'=YdR^JPU48n^m7X5
	5?q">\gi3:I2.tlHa2kLdnoN(K*&<IDGrq[41^#7_?BNhN_AnL8J[2QW8G_b_C?82b9`%ZL-BM!cI=
	gs8P">TEDgK5d0'PU-<B\A/!Mf[p2Z#e5,>Z<QWH8`+mAJ*PfV=cf&BK,:i%:/[k8<eXQhlN^P26'`
	33&_ou9:U_Qf><XfG8-`p?6ND%oo>X-i4sb?ku.JnTh:ELG!28``p2*I\X9nr!8S_Wbg36=OX6Yh&F
	sd7#0l6+-mlDDM!^O=e@mb[9h*\IqINB'Fcl[c3HI*+1u";X"C"AlRGFIW[.;BT<2I',n<$nfbV3$O
	E7#6.J,>"MR'H7sL5&7:R2+2Ur1996NQ2QGBnSiR'm'`F8GDgPS;*TD;DlbCnb:VF[%Dqt,cr#Nf<7
	W.<FBK"P4ZtU:`?Bfj>ZPG'hdG>.^Vg'$=`%H+%(Lmd&th0c3h-j=9j4Xdi88_p4Tat%I)3be#m@1C
	6$r*D4c&M9iK\%;WEQkdUNYAkrBGQ$U^o\U$VYQ[?4#:/j8B,iS^c(^%WBSc$BmJFpDFKfQLY/7Gtu
	@D$X4=eT1LIFK_+-WsCO)7e9K`d=#G!S70TMIXc8Ul7rnk]6Aj:l8@q\H'%J]k<9Lr/!FiqUd?(4g(
	K9QX.jK\cf*t0K&>bq[!BlJr=F;"*JCiL3:4QTI2Gt+(4k>jZ#tC8_%3$nf-P2eJ($.5`nnN1%6)e>
	+_).k<r@bNIYuM74?:?aY?hU4.;EXnHeads=E-?=#mT!rH")lG./HoI\9;LYl'dI>+a+F14bNHVBRa
	(r%/Kl>>We?_oW519qW@k@.LMZ&aF<67Ip.@uH8Xj,X?+M('C5t1rr.BE3b&W]+8_7^Ruf5j@@T&`m
	:Me6Vj)8uB2a5-VJ6pK%-i[X5pp>khM;?0I5=uWW+X0D]5TNHI36E5,?un`OJO6IqUor.-8Mg3@j#9
	@7]0G_iTB-m0EguN"@WKj?)1h;acVjNJd7EKAfR_2auMGVOh1uOZYAun4JaL3GT7GkdhIZ+;3Ceg)V
	%kHD4,c/-n0$H$R[s"2.l5*U66P+L5IJ/DQSWEqo`[1a-Els.*crQ:%Z[^H:!u'9?V%+o[E$F1!u/u
	F,j\LfVW7U^L/bC?mlKF+L&5Ck"D<T!t^)GnmE#1KsF]eEV4aYU9qSt16+3hr4WEf\l+%q]PWP*mm@
	fk5tVDt^Z>cGL2Gf$32:PuhAAJnbD9J@b<oARU]`s7.k#:E-m<8c&qH-3#$iYV8kqX.7`j1'nmo\R8
	qg4sLWIIVYd&m\odZfX?(e:7r#-j@0n0(E$@;@.6!Y'0ib(pM@eTfg.g+bumKMMA*RLW](Nf@dMp?7
	KU95,9IeRoW-KjTU\#f?,T33n3qFI+)+5"dU,T]/RFB31[=hT+4kdt>ClpX1T=56mc!TT,Fms--,.@
	IaQOFb"A)nr0'PVpM3a"U2@dN;RpgAQTOnF6'1]Qtm$,Kf/#=U?:!G`%Z:FRmX=ZjB*gfc]%\!qMsZ
	-HG/Ahr<H@>Nla1J+h`a#k2o/_q`atA#l-S(J\Cfi"pLNNVM#!g4s-4f>:<<:lbR?p?Ki8&k@msp<Q
	ttCDA'iJ&CZ\ouCHY#M@[#FLic5,4ingSfG\ZlKIUUe@gCV*oJVtEFh1p.lceqS]"4+IFM5]$,-Hl!
	@%jo7m]ND1=FX^s*EhZd*^P;Re&7n;,B"f?SRZV-EAfn*E\'9<=LLd0<0XZWtoc%>)1K3^4h^(31)M
	(4ClW5BR4265/bH?EMT,H[EA@R-;21I_Z2u5e/,O-CI?AP[97S=^Uou$0<3IpFO'M]gdA%8Ss!f6#5
	dBm6F$/22_k/]*FBX@pHd630<[gihiH5GCV8HuUL7dRkMlrg79u_(HSfHYq^N7dhr_WR=LIaf?=R.3
	i\KYWGaJ.4<g=t'-AP<@IEuJNRHX'1AY*D`fX>nKLk*_H+Hp"ZgEbe6jXBOUp1rOt^&i/OAKbm_+:M
	QtTecd<1VLp"q1Du5d!Je!:%+a;'7PeZdZg(hG`r;Xa'*G`?u(ALMJkk**>=kM^tI:[EH?V;T!O[gB
	dni%ae\/1K-Kg4kJ-UD>If6C)e[/VG'Sq5gP&^qJab'(LU5&$jGe49!@q\h=5G8Jc^SlbWS2c+LQ4f
	?q%N\;n!rA]B/m.cI%4f:Ro1ROKrooBk1!Hr]T;@M*>(uBiXGW)F+$!r:W;L_qN>G`R8g.ZbP*hV/W
	IMH+-\sjm:VtIhI0A2$8+:1ERj[d/jrn=q=pud)Jf0YZ[sl4[nNU\LgN"-Y=taK5/O3fj<XK]jCE<q
	_Wd,K2%s/oj[oE%$WAB%cm";4EA4$C=%Air]`sW"&\+HnCQo!u?J'uTAV);]cuOLl"X_EpK-7%gV+)
	#MUGqYGY&^,HN.5BLSg'G&f>C&;,r>Hl-6M*ZCmca$bJS+-k87h`Je[?Q.\W\;*es%E<T;6Zg($^0m
	.&rFJ*XhNVmYg6r;94Y+@jRiDOR1@pIf"(%_9iPQDT]rJY\/2=uC@fa/NA'VJfqU-F3);h\^rbX2^e
	b@gd/6^D[;.fP$E1:a68C\e'&]4P_+KBb,hph-0OPLeb`31UJ5<U8b-LYVI9^PhR0ll1=GQY13o,O'
	KQ!0AiPLIq"%A,fej=dspoODA]gcr)g(bOWrm5S]FOlKWZmIoh9(a;jS#kiGPg]+:tRqjCMZ$QJn6n
	@]'G""G=&3d0?d1N!f(HlN2`mdNbUho,l&24$/Hj^nsjW%-lK$s1PXWS"gBkI=,%eLH9A8UuTV^4ZI
	WGZC54%&%k8Udq5OcJ\4-O^*Vht9)+E%F$5:6A^ca9@r72l+QE:#Ln;0jFc>5`.JT:2Hgo:mIIt_J&
	[TjZN6E`[T!WV8p_%G[,i-<_n,AidS-#K$e#$,NGVs5lqK8iIR=Bb@GofQ!lmoH)j,nmJd3+5R)(?Q
	s;Q/c,H2WSsVbkpA"CpH(,NA$@Kq["5n^+B\9Q!ij?S*H7A`DFKmHe.>l8MU4/iHjMD4"W6]R2bV0T
	db"-bf&c^ARQ/$MnAh>kIFI$*hVlY\!EDf/=R\Y3'm''6d@6f(mY8BY;OlWp8sUclBhPgq-P""-!Yi
	)Obg,_PqJ/Eo(3MhYiX"\[=G"Fm<#De4D<0SQWQLk-X5j>4q\TQ$'h56h^!L5#ZR+OnD48Lf776eqW
	F#OH7n9r@d?O4EB1k%-c2lg*'&nF,glI8;pNW?H%qpcV_E*^BrjYFB*H?aZT#ibMr'[q`au)S=,59&
	UKat@P-o2Zd.!)Z7LP/f3C3VJj,"D^Iee,l>(]6QA+W#d/h.Cbd)N?*m+*-P3QVQIiXa7f(Vp6/H]K
	+Z-tie(it-8Fl=UMJKb)hUcAX$j]6/g^\kUumdUZ(QLJ45KmaH]GH"#m$I&eEf'lT;O`VI2<=n20B#
	gLU_tLIR:";Ah9nBFuAGiT4kDMGrLGi(Np<IHUlc=+8r>YUnpQo,k+!1sOI</,FgIBL^273k`K2UfL
	r8Ea'VBj%o"%I4hO.XE?o9>ooa,2#K[VS-6H<<NRaRJrT8I4,H^hh>jAlpiM5(.IHW\HrRFZ[)&5g&
	+;=LMg+J).cq)u.31D^FAL46tkUl[.@R^2dgjJNUf*(_;,r%/q_oP%8*IoK03`dS^X+GpC)*-%U)#L
	h_?PP2*A/khfnnr_[ck/%(6`BrO;2C0F4tTD0Cs-ZUi/jFm`^)N)+^^o_*N\S#EBi@0)pCBCdQhp%b
	qk`giaRn)E8KqWn)9GlIe/o7TKo$6_!HWrARTaot[?1"N'9@XiRZ\OMk<I&8<^K/r@ffXT*?p^JtB\
	\fh80`=t4fMrc)qgFTSgW3ed@nds@;kJUQY_)IDe6)cf""hW8TO.bC,[^rrqZ6\,\JoA_;Fk-Au]`C
	hjVD%H'69'nRn7-^@g"(;3jr;+$]&'="2=Fi#2036[2oZ^.Dn1!eYA$jAa-gVg.bhOnWdrjQqoH/io
	AsE?G,\$;p2P%\uUW&!5"7JqRtA&3nf.Y4YYoP$"C^XnAQ0Wn`n8MhaE_IC;X:9$cVJbO]dU/GICQR
	ncUFj^+d%E1SUQ"%Bir_UR`[r*fdGK])PH^`Wc3#VZO8+9Ds<+G^#M&-sJq+9[9%0F34P!XqE9Hk8:
	Jcg?W2G7Cb'0!Qp^>0T.fm65sGX]]cSM.\)iJ*l03Lhnmi4-u!Xd&[Q5cT6"56VQ8RJe:JR9E/@O%Y
	Dc`o\^L&>W9M3n^:do:R4]G5I5hVl8!P%ZdsiPrjA'^B.Zb132:<:RL>M=_&?332bQT2/Z6u@F-mB3
	5)mASTLj6uLcA"Ls0+9Hr#AOLriN'of36%`[4K.e%7924g/iHLUSB'iC=K=Ns#X5]K*FO==F0$legV
	B,-P<$r"@(Qp#D30<^+)KB7Y5hr/E*=*)MD[L>E&eb.">8Mp?o!6=7k?;fmg%P.XWbDP-\=?GP/5UK
	)<!:)qpRKdq_TehnuH#_s)b+04al_*2`V>(*rTk?C]q<BO&5qr3^T0#52d>G?6_>ckS[JPb?ChK1)?
	b_M-4VEIl%tAV`PmT26GAG'/VX-^;5u`31KMXBrY.g/lW]i@$WbMXr2_EAo6YZ1CJZ[N;uHI/I,=ro
	_lHIobC3J8&D%\g0^Nls8r,:b!QH]t=0=MX63[_=tlmE;LXS#RKL(]p3aX,`'0gpaP:G\8c$]VG-#^
	8<M7=H&gKsr%Y5o:QE0H*l3'<Ro9EPI.IYQHS@J<.tlXu_?dT!3ZGaF/gA<6f_/A>\S<$U+*(hNn`1
	gpXOGo+;-+s>N^r^'7q(eD+o($79:^M\A7h3L]ooDOB&L/KH/Vb%St*X[>sH7F,5[I6r6.0tZ2<S"Y
	p;h#?ZuF/5]g[:(J`KibU>.'0M%9Oj1=2Q;\(.OUhH;DOfjtr>Z7.D#W$02(WVQCKGLPsrK.n'dsEc
	t]2Sf`g/"Ojq<@Y_[;4!;OL7CH5?SQt1tr/:Vn0%BI031Bkl_t-4a@\'5oG%$Nf1To[`h_J<Ksb4qt
	l>KTu6T[(l%S;l7!9BS_Q=2%V?!-;VWrWI;CI[Kq+oKd+hS4)&e)gR4@NVR*e^\,S\+feWe^uEo\+@
	7!!0I2hc"3dS::(I/?3A['PNEf,?P`SM(Ug_-1AFqa"->ic*nmEr<HC1(qnc7mFIQfH%L8/Lr5t6>_
	_R$!f_0nHto8`o_Rs/Upf,(ZkJ!WqsWuMS6%t/!6@)]>hhHNM*P#;pg=ahr9RA`>S`tgb;81d^*pi7
	K<Di:J!r?<"J!PBW'lGXtO=#dp;`^pd$Mf'jFZhg,p:#5H1i0^VS.=inpdG;uKiJe7.kf.WF7()`SW
	.SrsM7"QB2C$l`;lp%u#ZFphSa.,r<*Ujh<@I-q11P9j4raLV?U?QoANNK(VeVrG.Pha^Pt@$Y@X)g
	?NC?jT02\ntPI("Tio?YD,ks3(DT_)_?/ON2Hm<gX_N2_U`-en&b(.nYhOYB(1:SC=c2Tm^-6;2I?/
	6B[ZLs6-ob#n<9eccVUlHT)&H/soT6@#uMDJ#ED/-AH$T_Fo".agV:Nkbe30<bTjK$W%fbN-hh@6=_
	A"aK"(lb%.M:X/W@JmH$c!G#3iG8._q]O<Z,#>A_R/c9c8n,VB8(_#Wr:odmfsq`jr7AD^G=^2Qugl
	htGO3=R?R&cm?Dp'NoC@Ce\(.C"(?2Kh6_dKbE$]jZ/$CbRW<nN3qLQ`DmPC@(I6ga54Ym$IMCHTjE
	gjV,e!MCdH*#@t:5^o-(5_jOXNLtsd$D7B=KlJaPJ#;u.omgOAHCW>,25TR^/WBVot<qj1I_4X#n&u
	NY)/]5s/`_9B:0i.8hes?[[r>G4eNhahs"K>EOVYc$=R>X.Yo_R[`HMrg!d]0D`W5HBY0`J0/.Y=XG
	jWM`Grc$pN[g]*"k2.Mper`_lLW*OP)&%EbASH./paDTf@oKNCS86_F%0nX7d"G5k-Mk&P,5,ng6OE
	J2/L`?GUrZCq.)?#u:_HV$8!='X'EUQ'(kb-c!=&(D.?4uZW3/GHz8OZBBY!QNJ
	ASCII85End
End

// PNG: width= 119, height= 120
Picture NSFLogo
	ASCII85Begin
	M,6r;%14!\!!!!.8Ou6I!!!&T!!!&X#Qau+!.]>fF8u:@$#iF<ErZ2%%KHJj%KXe^Tn<=F!"j<A=EI
	J[Aor6*Eb,5BB5_f5:i^J$6(dBA!$D856pXdsSF!q5\/]4.m9@,Bp[6m@HV<)8)N?("R2M@l1IKH,%
	E@<\_<,-QI.4DE0ui2)#Q)>*j)DM_irCtA$sXW*jG?P?P"*kJD/J[1GN\DZ9'<s-XZhg>7<:_hP4-$
	^HDdZaeQ6++<U/aKX4OCB;5B&oSTsjNqMuaYrC3Zpc6'AZg;H&N7_5api<[c365k:eHE&kI?e)`M;R
	PE%p/VfK`N?+#J^(TuQM^IdoIOdkqc*=R3qD!,kOS1]FQ<#J"LNWhesklKd5mU_,SGr%k<e`9(5YGR
	(eGdk,*>D1,?a2U!<7OM(k@f*kO%8W"9Kg"Kt=h?^StMoq>=X@l`,l@e%%k!eLd$(6T)QQb"O:eC/=
	0n4@f1ZB\dk42Tif?B4hEc3EQhR^MrBLel"FsQLA\:[q*KI,*=9CP)$>6,SJ'enk^*Y7%tMiR.<8'B
	sJoXVjg#JXr;[A>j("roDN$%+37`/&t#`M`?VCC!dKeCQPum<i1_/jD<gU8[sVBQBDE#sPMZE=/=uB
	^s4#'16ilgh5*j4W-SW(Sq7b+V(E2!,j0=I?cZHnYZQbN&oH-]r:_nmUU)6HCas)s='I*o_53Hr_&q
	:<7p+57]:3N$\.h(!;Qd0;04b"/#EnA)i-Vck!l:_gSjo%ss=7t43mAb?8gJi$('T-mr`CtP?G._^q
	`>PoBon^"ain!6LA$#8bbj7BTjPcV%aZ!dn80j(TjIn+;M*s(]4Hr8YOXN[3VL5N]inq]bH#`uo[7q
	q9\Zq0[3<X6M!bR&8q42qBGHF^&?.@%RWp\c'>`6bQ#uqpQ?.C:HM>]Q>qOb`ZHmTotC9=K#68kTRK
	+?YpW"/sRM'N7;kYs@Z5JNQ2Gq&Qd//!e-0p4Y`73[jB7ZrP480ehe8A^V;YrM0=3M:9Khb0^p>FGL
	0+PDe%S;uTM[7JJSkHhZgT+TF1)M"Tr)*mrQ4L,l/[BceGH%PJ?@1['Ob`pG,&[/[gHCnh$S7>X5G(
	`><$2P_eTC4hYEN/D6id<\rT8/SJas)s='I1^e=X4W:@O-4IMaSadN$M*m*/b],8c2=2?HiCRc%Gc!
	=^G-O&0UurPlOcAHS59-N:U:GVg`rW-$YV0"?ZPt%,SmM6`Q_A3Ml#4&HL=@L[?[Kr4-HCB9I[_-?[
	qt[\$Rml5KA7)83&q(WTKl,RUO]ag:@0oH-:\em!53-/XqU,*=9CP)$>6,SJ'enk^*Y7%tMiR.<7<5
	ePa1^e\fVWKE7UF-X^9<A2[jU`CT\+dYJ1`6`eTPg'=jBskUJl;TN1T4<>-fqPLEVWUplQeB&I+X>_
	4a-<3sc@djC4Edp.kN:-l0Td>PogP5(U?_['%QX[aoJ<aJbN([GmqpC[AB%%^OXN\^LU'Gr'#dE4:_
	nmUU)6Ihni<!L,.GCLi(Z,R4?iLd<:,"\Wa;hkU?Z1lSFkHBE9cN2Q.VsXUT+F=`)s-n?Pi;&s-al"
	l$J>g:=tf?gO\fN,1C\5@qh>;nDEZd$18j)qrD_[l2an2oiX<kR;(+eF*\B]mQM<@m3</?X/^ALq-"
	bq_FG$*D[2c?_5G#.s6rA!&*K-qk-]&*Z(J1l%I+V*j&uRLr]"?8Nr40&NZWO3eV,@Ds7co%NN7!0"
	%VY4L&FDahdFen-`O$$s45[qoK5dD>U0r=@O-4IMaSadN$JpFO[paTOb>0U@s'(9ki$6b0aL\>F!Xh
	a;rG4."?:F/DkF%rB(r:9-V']Y5t48*_@B7+]-d2f1JRXNUCLD.DBlWWUE'CHB@cM/]U0o_jMa$5.3
	"NK;'oYYhk>L@3Lp!;1,;,Km[C.33Qsjc^81%j@umZO]BNp-gGYTU\$':JCfA%Nn`W6Y\V,&WHA""t
	0$^N^i`qX)r\fu$!+Yf-gQ`'bX+LhB0Z$)'imBp.IMtH,k$@Kr[/+J'7J'k[>4auXP&JJeO[p02a[9
	2V&rC'CGpnS=,#O:E9_fZd1MojEI(g26==B@:;moEmUXMP7b+AN]WXg2$#_-W@FcPh$?IcS;[c\K?+
	/i*oaYKodi5f[Kpjt*?3)6;H-^\%PVru7J$CGb<!A7W\&jQ%C\0?nmBRud6W?5DQ+*d3q#ItC%dncr
	hCHpHtjATEt&Brk41!bRT?[8I-]Q=U4)poBFr2s0<Y#-n]+1ac:#.4Hk>arS,JE94=E*Z[E[3&hLSW
	M-FBENEL6/=AORR,sjBp&4up2'Q]p:O%1>U0r=@O-4IMaSadN$JpFO[paTOb>0UA$H9)fl99]fjHn@
	K:ITKJ4I"An1pO;"5U9ub]IjeYc;JSa@t6tr>JZt]j"HQV/S!1a$@<JfQ7_1*1B@2j"LNRD)Y>(/S$
	';Fngl!2.UL4N=*Zmfb"8XO^"1V=1(_@?H:!O>BT^gF'4I:hSA=#me_sCo7^UQ%h)d;l;Bi]4ZTNW,
	NP%QI4fT;doLT7c*nWoHq8>,Y$t.lk7=T(<]R#A^0W@H5g*RuA?IhHqfB5:0>t7kd+W!EHmIk8F"7!
	_//!e-0p4Y`73[jB7ZrP480ehe8A^V;Z1Kj2G7=C9rWE-Y'qSRR)U;s24^1MEaS!]USst%"eb7Eg<@
	=a&SO:+ph14t%2%MmOF8TqV^>'u'm'TY/+n?^K%uf$F;('fMV"kG=ZT*[;Uf1[DRZ;Hj'3"<@#$^gh
	HsSKeWu>5lmeD62:EM`nC<M?]3DJ0FR2j549N+,q$G"9\#4e+I(XQNoZA>UCN.pX4S>SXoE%R_(K0"
	g..a;4f8b-qd/r:D-<:Wad,SGrC,^Cer6m>Ke,S+IK80j(TKINO'79rXRn/j!29e`WuW%XZPiSW.,!
	aJ_Q0C%WBWi?:Q$c94>\)eP'EheNIM,jk_ZaC("n61f6[S715h*Iq0r"?:dAnKCOY2.%Rk*'2G4W,q
	PRkd8&>_3sY4hKVsmcgL:&.e-XE[^+EM=E,JijdIdn,gq,_H_43m)'@l0@h`!GrglDArE%oC``209O
	Sl9a7t".E5!*!,tBSJgMu1,:RL(`-@)lP:.3jp*/cuL-8-rFiU_N2%reJ8TV6E:$%8t5cD>(N73[jB
	7ZrP480ehe8FfRmM+"'T8XT'/(.Hhi+ls)9#'iZ%T2*--(29.DMs1Z3@'!h,<$)%l#-leV1>$Tp_#Z
	HQ+PWU@!3\M.r4&c)kE%dQp>Oc^\SI8+Dn4m<<KE*!WOf-;*6GB/j'm97/Gk:EOA1i`2Vg_Al<54kO
	sR!l#+3^=#EIb]HSD$1?h\/4B/3l#`?*0d8Dm\H%C#EFl"="Elo6bhO,Ql5\j(gP$b_Sd2*-Ehp[s(
	42QN&sh4e53%_YuK:tm=!H!^jdH>3LA-cNf:f\T515<c2(lD_k8hI9W:r[$Hd73[jB7ZrP480ehe8F
	fRmM+"'T8XT'/(2$unL@TZj>ddr!7>)g$YsH(f>&E=:LKXCYdl&h&^'?2KBn8c-c@UU2qSXOWq\o#F
	DS,]rWZKlB[An'o6ec+CCJFSOrIB:0C%,IWgT0W=$o4CJ[NA=gGm3!V:4TCV!TbY4e0cr0F8#a+qsC
	l-&V&P2r<[2^Y/XTXPh2FVf6cg9j=G6*r`X,6QZ<#OQW61o$9e-`Mob<Woje"kK^3<8QX!>GHp)cf@
	8Os72?Pj#]nG6s&UE+gmKZ:u3"4`s2GEFYRu!X`aZ!dn80j(TjIn+;M*s(]4Hr8YOXN[[n!UKI_P?B
	Ai5#gM?T=^.H`E=D:a"o!;uWjegUHJ#:HGfl@-dZVF)6KXIbsVRs7J_$kB.-=4ZoaH)Y/8WkE0tY#r
	c7aX'gi7$f&:#:9&Vh!FmPMmD-dO*-[up(`!0leb?`NK;qZl_-q,DZOmh6%4DA58Re)&%*YWk\K>ou
	NP*JQ)k>E"0[Wh[Aa\<_8_#=KbZi-)Gr9r2S'gIj[^'2Z)DKY0.<f&rZ3U\O/E[4q[#IT=13=+Ucj"
	cZO!"@&<R7gVqiO'QAb>_,JdrcJ6Ie5Qc)S2b]2\/M+p5D(6r-$cK$JSh.r"pK>9=Vnc-sJrP9G1[B
	lIB7c97m%QQX6#2S,>MJnp,RAX,YkoZXpOPXAnX`cS9+Rq)K/1tHis6+2X7i4>O6P&JJeO[p02a[92
	V&rC'CGpnS=,#O;@hD=7]!Z;::.f?j!'McoHgt7)8L3:Y$0Pu&N?2D#[S&O7h!Ou.9$+L_5^UR*J/r
	VNd&b@Rg8uhSi0Q,\iB'8,X)Kd_h_npEZNCA49JKp4n!:ubQhhc>"EPD)WqenD?<1PUKbe&%N75@AN
	2S^1D)H`\A"2sJ8f%"n^B9RbLe:TC#WF$aPpe`,<3t/q@Rm,u7:rE!%*OTfps,3,DS1%n(U-,S[Wt"
	O%:TW?[!K7>ACP4OVZE<KsIFiHnre,j1QV:f#obZ"'E-2?;ek7mE8SN.IWd@ATX8:=cYi^p,^m@Ctf
	Csj:^8C0)o>iN:Hi7/'rW$Ga1pCRF!2DKCFhYbUg"rM5k\f@*krS)>G-<nTHC%RL2+l?0T0`VRNY^T
	`XTkq0.SZH04Ht4l(5YGR(eGdk,*>D1,KW;U,SGrCV":0,F-!qL3_02TXL:<F/E#k;3,(:%m/tLk-j
	)\KH4u5j6i53k^^"'qE7HQ[.uhQq;cMfK$uhV8SqA-<-`4P^MB%8(+1th.ou<N%GOO7alAgF:GP0-Y
	?0]DFOudp`\]a4"VYcb-YQ]R2+NA&lE%K&Lhf^Y#o)+[&[Fk[m%3fcA6jg=lo2Eij>hJArZ;CiBY#-
	]@*a$QN[S&G)*I,7T"8NZY?!j)22LF*$0(1eQ[NC,$7NV)5g>6aX%bh`b1QfS&g*Z4-5^'JH?k+:3#
	=!7:LA).4-7<c6!<2rQoPVGR&#f@"rdRc;p:YCbGj9p]DE@Db-007PoK*&Yk4AObEc4MiCEj2V59-2
	Z(:ip)QV+b0pHA"_<F9eFD)djhfQ<#-dr8"Qq=oK(Dos8d8/*;j6WkZIM..`U.#UJ;;2h=Bn(,fT[>
	=j[Lbgred50%JJ:"Fr0=\:#f;^mU+[;Zs+[[L)+^Ri`eNIj#>;&:(C`QO-_#%"A`b&/!\KChG#HE7D
	WQ/"em<)L0qU3R6'CY]&oON<+[_M_iS6+*mV`W9MnCE?gRH"bMT0R;6Y%qoPp#pRXTjC5b^Q;qiLaT
	bGrl;ko39eB(XK#(?U&X!!,$=Y-)4oM,or2`7i$m4dap[>oKH*+qdo5c!m_7U'<F7J4D$Km!l.ha5I
	nrmq6_6'+qb$Wfp1<iA0\>_ip"C=ed>:58cdA56n(=nMp8f;hkQBj@WqtX^bhGcsq+ar!.At.[OGJM
	o^TZoHZ1X5FGgH=L1,lAJq0gmk)Q_gSH#6L*M9e1!fRfMHkD&T!U\bm@UPte"m2G,eZAeB<Hj#ib07
	UlX@Rj"#>e"mWT7/`=:\%4_,SGrC,^Cer6m>Ke,S+IK80j(Tc:8g\Qe:K20EqL@m*S='4]8)gf+*,R
	*BsTJ*Do;nQ6#0NB,L,&#3894$uf)h9tehWE5:!]E6Q%)qE;QQc]=-^Dqj+*]1:DJ*\b>&]_f0<SKE
	N_<RV!9p*;7iFZKcilRi&m`^]sh^a7<L$EQ6H"HVgRU"Z=XYi)rYCt(dr_81O)<BWDRp=HJ-hgRdV`
	e*[OX*UHLG'nBEq`IK!"go';c"du\>fRhUcJ]b4_"cUcjMe:H_ZQKNE:*4\6^"a2.AsE.q?Og#2iPT
	]gtRlIPF_q6eL<b0?l8L^0&sWs7=P&U)hX_##N($Y<WADcp[#R.-Ph962HR/UX06uAWZSbFZ`8K>a`
	"0TRObTHT"=AhWnr'H0Ap(`K>JsrIokJqZqfaCR@-DQpYFO9qES(^EW<0nj7AN^Gd/&d\;qp>BB\!_
	:]2+Dm$0b1,i=hT,*=9CP)$>6,SJ'enk^*Y7%tO_]_<jr'#DF!1'&:dW9^MB;hKL+@H@^G<iQF+)qs
	5>""E`m,k[V4MstX?gKH^n@qe!tD\EV/i5'b>^&JtS_UlODq6mnZ?)_SR6f-?-`l;bW?TUi8DuVa\T
	^#7@\#S.U@f-U.Gdj_a0Rec/m_K4rF0u4<qX#_j-Ul_2(N0<fh_>K<D\uoU:$U9;cplUXYpmo=+mL0
	5,a#"PmZ8ld1)W(@3'mAc@0ahFgA!;k/)-1bgoA6gli`Q8SHMH+>Eh]W#4&Y&fOg6?nfGr!0^Zn[4Y
	dF!G00qLmOdA,CFe';O1pP4Ic12)Nq)1Lm@#oV:GKogoLL>&?^\N5eT]pD5?,=A,P\R,*)guU!UiHL
	-+jaZd98;"*7q)PHS)hC:$Ro[[*VHbBc17M:5$%Ia:ht+ms=^MWB+>;VJ81!No(u:I4!)3k3%N\S$G
	R1'#dE4:_nmUU)6HCas)s='I01C5%TUOco,^9*b>H3CQC[e?gntfA`U/Pq[<=AH4%1cjUr&"Xb,FFW
	NY%8,5eSArSXTk)rUP*lRmEKp[8@UIaA$'+)s=JQDZb$G8;o0MDW[R\p>'YTJ\n%]0l[IZYX)5M_<$
	Li"X32kTi.MOTitNp`/DY#(Y:t&if5s(;)iG(!JC.r38@O*&b_P[e(c!TocuneOM(/6RT<["N63CRK
	s8$G0(81>%"<Mb,1PA+MTn"`-OsQL.TH0%a7]he13,PNDh2ZT.<KDO#T&#l%k6PO6!Rj?jH:;BJc>+
	jNj[O2'XgR,.4VT]6GFU[OI[lU>CXB02hJ4mmO>NGJ=X%CffOXf:1^)+o08$)s]dK3$/@FFZX!jY)>
	`=-cV]&O7ogbN;ob:rY)^^I%dQ#7)O(cT4X8Y!p;\1HrCf;7%tMi*m,[h8/*;j6WkZIM.3:PSgh9:J
	sqr,#LjFFQlEN/:Yk".n7J+MfTXuST=6Q7_G(8ad[AdPWnt,k=j4TMII0.A0V<S,*m=^^+>;_A^\>b
	cIpiT%9`IR?a`ks"e"P?:ObSiX%HFp6pd=XW_*&l(%+]^M1$n)."_8rB;aXh8hm&Kf54p(NQOS>V<.
	j*%fI;b,h8K6D0%aWnZ7/HTXEh@1g.\9.TM@Kd\qY!u)jh=F`uKgc>RNWGV61%?o>u8oZYKu`f-\24
	Ql*kde1Fparf%jr*Der>TkCT)b['/b)tM'ORAqD<HXR+gZT?F2HM7S&YDmm+2q$X0BqIAgNk%k1O]>
	kR^Y[JUY6.s<5oWMt[b(MMWXo*u?)k=^Y?^[=Xh/mY;EmO,XO<sP06oU0D=T%1.i^d2HS(H;Xm/Q_G
	`A_/ilJL^[/L+ib!I$0H2+f=4<1Xt,SL'rPrt:",*=9CP)$>6,SJ'ekC*%mk^ulXM"`c`m1tP`Nplk
	JWq@\UCRXg8IHj&Jc@QQBCiHl;*4XWl5?Qn>%!%"C4ZKV0.rTj,WjhF$O02CS.sj/p%DGoG5rJV\?S
	gZA4^!=pq2n&6QJVWAfP\SMp>(@B9U#3/W+$1qF't@3Wpl=WYX,W<gLk;0qQK-PcGn-AYiC!2gotDM
	](C^GBP1@#-dUlD^#:-W`)r[+ABhqQBP$PZAnu=R]\Yj)CKEt]Z#?2i<>6snf%4h.7`l4`Lj4(QhXg
	8KXI1YSoJ#&[$3onE=q*X=X[>;0%V8$FPj^=\!5J.&Y/,E4%8e_bSSoA(=</40aL:"[2CShj+J4"mN
	P+`M"8AeKYFJF3?Q]"%;9!g^#&'PcE89:Yq"VZTf'<$MN;np)rILuT^"Y9e2"d'.HuL[QFgO#p#K]m
	[M*rQ8cQ[W_MaSadN$JpFO[paTOj8<GEkn9b!!(-haj<\?gBr6$QRAYmdi.;`U^0D(#nn:tAJ(Rim9
	ohE'kCkaN.<^MB#/<hZXA9C7i^3R:j&OfD'J7VQUmk]9R(fspZUG5Ic:@IenDs>S&p5bGnGG<%1:Kj
	T66:mp$EWLV_q]_f02G[^FLo$PL]raXa1hF93E.@#<&"qI[X#A5+N`KmY1rnhPh&R,_*0Y%&Rk7_7/
	_g^ddu.gQuSKoMq8a?0VZ.&ta$;W+Vc`m>D02aP/Y)TjKJXm_#u%^?c95Dd'XJ%O5CjX[^6kI59kB4
	8@RFpr:d_^?L?mYIO:(Yj@<9q%Aq^Xm*>J5(,SpdWdMRS7=%,Fm+-r:XBD%Si2Rrq/V+6o_E9i_b?N
	%7>O5D$Fl*3@K4DV8;qPW*!F/<n9HGXVCW@:6nsiePXQdY-q9ATZ:H5R`CT/T;mm_;HP/tT>605t%t
	K0&%;eu8aqSk#2JrTNC'W[@#nMEliif:AR0Ot+>D>'sXQ-h$'QMG[r`74++5$kqG&lXk`R`b*"cVWl
	I1rW0qCq\MKCX:D3K1fIEF-1<3*k):hi*@mRcKkg;K'.[KD=2!%Zp/4<A<;Gc!-D&SNY,%.(4*/&S:
	rr-K_XNJ5K(D@GXW;Vb[*HTe8(i[1id\P<Zb0_4:7h(rNC,`Hq=<3:]Z7f4S+NP>D*ELp_>e"lK/g)
	Oj_-7lC^AJ"-"\gE+A`oihG!gR.&mGCB&^]&:H-,Vm<Qnc4(-LF3XNo#b`#<;"m5Yi_$fNB?2acVQ:
	5Pprg%:)hfOa6WsdIU]qR/G5=)rC8HDrffbfiW81%OX'kN*bmGOZW5g*Ia-W>O-4G(,*>D1,KW;U,S
	GrC,^Cer6m>KeFP\fbNV\0.oM8.E;kRu@qZIaC`rggmeA8KR=-0'?1r*`U@]Z.2hD[+g::IksUZsG#
	O\megq(VfV%%hJ.U?bd\B>B<6:P01,q`aMc6RTZRF-OXKg&TD;KubB[S!XnJZA'#N[V$j&\DXT_Mf[
	2W1Ykeiif]"@IO^jcFkOc0Wt(HKJ;3H.%:"./neidrj#gU7rl,CO03358_tY=GT2tW"RrU+%T5,'\9
	LP8'5oTgpU1#b8/OMU"4^5rj/!J'Bd$eA%D<`!P\[Y*=q;2:H4S9lKSuuS+Jr"rUKm>IPi4OMhFlLd
	B.Ph=%qr)h%_ms\KU?W[N_7@5NRS-VN2W,T^48Fu<CFdKrn7pn)M%FGI6,=EJ+6VaoEP=9SRc.2rLP
	%>I&S8VZT3COf&]],WfP)O\GmGfOgU,8@IXUc]=X4W:@O-4IMaSadN$JpFO[paTOj8<N*)JFQ,6R(t
	aj<N$P[4:U5<,E*^[^dY+&R0,OM%aG+KSlS4%m*)">D&SlTu-U=Y58)0=AUa3\<%nI?/qX5B7>.*:5
	sT!fgt@^lGHiph0OTqX!lm"Fk5g_.PjjVbWF'<6p0ff%ZRmTFDBu+RV7W"#ou;iU*0gK3`(En1po_Q
	eh,g,$!l]^c_;@l^/NMQ,27Q6Lo>%_!!Wbj4"\YVnii&Lh/6'^""L=4%ML7HVGKh@_uV:Cgdb:2"oT
	o@AbG`5-Q'\VY:`^AUoGE[b$ARVC\epcQcIPO'H2,&*p$S`>U^=`I,*)@Eep-=S$)mA;b))cXP*=E*
	gT(]'W'tSEUa-ArsjC7WjU`GWLP"YIV"^I&r$%0QA=-r=odCR?4^l,4[CB&a&7=N)Q$\as)s='IV!i
	=X4W:@O-4IMaSadN-*o4AMZomOXFc('!#cY9<'V3i+k\I6`P$#^-T(-T"#QPQg/P0Z.4cI/RtDJ!h=
	7Z&M,fO!FFp0"Q0.Oq\N3p$&k`5eL<;*\?0VbkM']J('45AZN]Xck$o@$4P^=4[kNAZRW:)W;MMJEr
	S0<.O\'DOhmm<k?6KjJ;i>%G2%+I_R`@G>M<U(&a_.'XSF;pJZaPG-[2Q;O4c+SV&M\:J79Qnb*s[2
	C;bLNdI5S7e%49A91^/';TnosRM.P9e5GUOq[6sq&Ma#`!*daDQ9en+1,NrN">DBsr:TPZdUul&+o#
	'[2=0LVPhY#e?Wa>)5hqifBhK'r!XC7=L2`T;_ZIqRX<!L[N;f6i3OM4#0m8P!HTa0=J:8'W)k$?'K
	0MJP]dj,2nh_07=cUZ)9AW]M/MNQtn//!e-0p4Y`73[jB7QU"+1,g$@a9ZNB@"RVgn[KL)AuuBcl&U
	>d'30fKq29CjD)VQnCAfT/^1Z2nW`'(?Y4<41klu/CVO'$/T,[tI//7'CbR];`[E-tT=sC,?"P77Gl
	sqfYV)<5?;AuVjS\a4/&>S#Nr:duh3+G`*J(r7Wr3J!7Qj/,Z$oiKsI(2t8#C2h!WU8_nQYI@5Jpbh
	,(!9#(0Eq$\C?-["W/$jN@W#h,0^G,/nG-\<kMEN_r<XLi"X`\]V2]OFf.[^Fm3eQJDc71a,^gbT9_
	M:M-=rI0PRS8:R%Ik#esP!CIZf!APuh0V-40R*$NnKEQqh/9r50+kR:!67o:2^bO]?_"0eij(pe1kG
	Vi"UJ<es8jngq(=Fq)80?-(tg3^+&14h0Stm*idFW,&<'\+<nr9j&_SM..`U.#UJ;;2cb2AW]M/MNQ
	26VG([N[OCHl=^D?'o_>+-<S^aYcRKZl(%CM?]bA$H7:pOf$(1d;IHaO,]lOjI[CSsObRF?G4`_7+n
	\P1^h=_%lYuVg6f3<lO3+9`!RO`sH)&E/%XVS?P>G8cY6f=Y0ne?:/)!B\r[%r0O!$D856pXcj=RAe
	?TVI)";/Uq^5(3jqm8O3@hm1&<SN_;64,j.e1SjB!\!1rP%JX6sc5/*aCMUlV[0FXD&JNLQ0qTe4iA
	Jcac>CMmXf]AeIc&!?Wd]W,Ts#?L55/SBk=Nf1m\T:1#/01*%6>:4A[$$?THq1c$1`K`[*W#7SF8g\
	PRU@=FAiD:<q?9Fj;hQ@@@npjW2h)]ckh-Aq\]Ua:$^G-9uhSGgOc#_fA6?C<Td9<dAne=AUaRC^S:
	!e+6Ib7pi0<G0&DM^ZJ=22K;eK2r5\X.J<Ooo,*>D1,KW;U,SGrC,^Cer6m>KeV#(c$3pD,^'J?%u:
	%3m_?V#Z@3<L1>6S7;d2Wrn?N=Mf$K-TO2UuPW%EW_g3q8M`$pbX(<ph<_M4:\gpc<pTgm%3b`.SY.
	G#L^[VLhbSg(VfV>Wd`?t^T?_4ItHSE5;l0FcPn:%\;KWb5"Urc[CWoon+ql<G&;/krqpbHCFhIc%R
	M$@!VV#ti)Wk8Z5%a@Z8)?RX-hX[cJi*/5%SVnBA'PH2,f7;)e,E\m9`NX3/KNa\Ne\n!sXim0TpbD
	q35k=&qAMIJJ(=G;\-Y_HEh(bl\46)j.XMa2G9GZ7JNOj3A[Z"-/uf/_r.Q(>^1h"$c?A^4iE0T-G7
	5dNuu1r_dN"(K_$3UP5gtkT092U6CcZ1b`>c;3B4,*S:rhAo36Z:eX\P"[I<.h7FApGb=usR"8@71e
	VP3i]j/OaId*Dq;"\joni_lkqps[ID`)N//Xq.X2CC*J!t1"Mq8P;,)UPGMU?e#X5/g[N=DohJG6rS
	F^liWY,*>D1,KW;U,SGrC,^Cer6m>KeA9Hjq/kedZ7;!Z3RkX'&hs'a)L)N%?cJ.R<GO).;1a;W0d@
	`YF5#*KqH"@/lG\$oiaGELdmf'VtGoOag^SC7N3*'An)%I(:W\1`piO8K]qS#I]q)^cu#qbh0WHt]K
	IrqCmPNo'Jf@-.(T-[lP,sSS+f5rtWp>&BP%DG@3?QF2caFQdWZC$iQLLYI_gNFul2q#5chE'uCUIA
	meSu4g)bhS#o__pU1-e]DeL3hqndb!2pNemu2,&/.&opH$8I(BQTD]ZpqK4Q.jG%(JfeP0Oka0rhI^
	..R$*d[TY<F=DaSnjQ=CNourqa)>Ag`bcjchZLg=ZXZ0J:"UsbVq*?;>$nWm,qYm]3WsQ%8X7*JRq=
	ek.*sprfS_SaUL2A?I]R9pX?/1)8mN_Hi.rb^?"R'W&jG,TakB!O)qL"H>`6DA3EA'O+dE@N37k'mr
	'cUoGmsXXX8lLo:n.<XE437//!e-0p4Y`73[jB7ZrP480ehe8<uOmURV(RN;+4Ml_(me5J>[pV&jW2
	%ZY.ibYT;HFGbn5L?+g6,;?_lETHpuA5f9uCieM4&#ag#SuYjS]FBfn1B=%^22jP^`7UM"(h0oa=gS
	\]`MDi^"\r-oH./a*>uF&)52A2H:H$eM_O@YN[TKOSo=%/TFSc&Y.RoTBD=ChU97?*+QDWGo9uN\Li
	i:650fpE-_IH&OJAE*HAQb+]2R:oUbWUS=M:V2Do@?b@f=L@d.m97(qqEh*k$F_;L'II*qe6LXb(?I
	mp_0[q&<!&a6gm*$"W#mjCh:m8iH+8>IBfd_5CQ;Vcd'D"Rip;XiW=.d$Rq&+M),"kRg7oS^,CN^j@
	g&!i7L/'GoN*LqOSAA6@%7LpfiM[8SDYVeJ%T0#R7>4nF:@B?`<6;pO<dqXaruDCUfGrR9*f]&aj4Z
	L'7.?_"5WT9ObbdQhR,%P!REd.)7_A]tXk8ptSX6oBl2-K6[pL2eA+B,`7`FTe$h56nsiePXQdY-q:
	LaK39n"d9Yu:ZjCZq?9d72D,=8&_BN%%q[^M>_Iu*Y+E9[;%%:^[ehqEpj+e[VFalV1i]>`L<B&fdj
	0je]!MsPq";mb#OUTIN:9K-OJ,/MP<Eo8R<BGJN2HNtBI6?#3gk.!VLL#t)Y03'U@%.Q#_)M73i0>o
	t.f8e$V*NYOmspu)`:PX-2fO$DJ"*/POudlYb?`_d]V7=8L-b`#MQ#qMA>(Q+Y)h1Eb5>WCC&`tE8,
	X0l\6]9U5^/Hs3(A_GH5<XG2SC?o[7]UaWF3tiL395HCXf"cee[5DT-?aPr<r>!H=LP\e^'gTT1QMC
	rB!UGPRAdViUKA+kZS_UDmkeuU/Tpl'2uEm9#K<-^+]INeUn?ZrRY?YQJJ5.1f4cpaO'aoD4G,9cJ)
	<h3e@1>-]?k%4S%N^;"^sBj.=\_f;gq@_2\uq&Nc4cc.P/_pI4FP=6mMkYctPV*W'[&Z2XP=*J`2VH
	/:Q>6bY"-6m>Ke,S+IK80j(TjIn+;M*s(]otUG,>?)9O4D#dBlbmQ_%m8-u^s5gfIZrV7cHV/?^Bq6
	9^^&a*kd\n.+WQDdffetka&N#3>@*28Rc&ff$D,^mSU0V`\8NGM+PU;Ks6\hg;fs=t9%A4Hd;9=43F
	BQc4n:\hp2a`^X>Ah\;$5\*,5!X#<bo*_]fbHP%bRrGY`BWn?^?;!=4a\$,%9Pi9C%7,JFXJ-p!uLW
	7?=E14^[VT(D8iY6T9Y-YYUlMaHu;&^^##Aj%^QZXjP#ZX2O"%jHgt4J/p#d\CYIQA9Ma&XA?GE4mW
	"LjC1?$s8Atc)[0S,Gs7X%&i4D#S.U_G\6-YZ4B;L+c=CmB:KEU1EAE&O3*1j\r=`N<f=q#Ua"SR'#
	>7G@Kh:`dbS8>]C4T)dH,VjEI:1r>X#_,MK-/hI9i[6k`]]gEG`f!`RpI(KlpkB[P@$^ajoG8eg:4&
	.>!E>=;'Bk`a^0<tL&nDnMhWA3PXQdY-q9ATZ:H5R`CTPr(5YGR(o[n?:^ff04(d:"e_)DTCMVJI#H
	q9_Qa!<=.GNq:9I@'CrB-n5VfP)'#'ic8F*I!h<=]dO0!/3[rJo^tDl++Fl\^WJDeYOq2NNj3poX"c
	H@?$ipPr(IEu+YPe\N>K)6d_6pq'"`$"r<nk-:Jnp-+lu;[3,NTbao\(B*+I9$qc90[<],k7o>BYFS
	&$9#?LT$F!9o3l<bb!8R@NbFH3T0n.F$(L;Nl.^r)6[fo5]8(fHBjCoWjE5&.O]^WH7cFmqcp)?!3C
	^/W)%F@5=,(j+#J\>[:1HndRqJcVMP;rKiK<">k0h97YB9pmHnDk#G;iTYYBKbi*:D$7-X-CZ\7..C
	Yj'K'oc)Uc_K+Fr-e),UGeURF"^Oj@d2*X]Bc9i%7R1R&t/RGC@N4Bu+hgf@\iYptKpuFA5?#&ErAh
	uEe1qa8OaC!`q5)+NAd@ag:Pq"cg9GM@9WbZKKFV&#2/=h7a5jON<L:UQ,C*Jd2,`7TBTe$h56nsie
	PXQdY-q:MLE#ilf3fe'?3(p:ZG!&!/5h/L`#?<oHJD[/,-9-oN^/t<(j\ZOCf*.!$"4VK!9ZjTUQps
	$M$gDhjFlm\F-F(s?QC01hmu\r;Da3r^n3XkSeK7W\ab>qY2Q?FSecNb[>(B'PASC;]c^uG+D4eY7k
	k&o2U)+(nq3M2`)oR6\eA&.Xh"-;8AEhCg\]j?kSiO1o&[UVY$\E3rZXAEl][t8g?LRK!*?IqI-ORe
	#1H6.+fu46O/9elOdqP=FBS,hV,;Ach/A/$S#1dkL_ERQ$AL<d(Qi7K-Z.Emr\"u!3RS!KfZNnO>?c
	@H@VX&A<)Y^>n@XDJ&rRgPUqg`8nJ#bHC`!\$L7j`M+btV]JrgRgI<qXXC!fuqI]91(+Fn!\uV;Fii
	oAh!siEZ4P\?@-g2tK%gD6]'AQuaXiVs4ulL`HldBUP77"MH&=*:Td>Gdh>KO@)1sK6Qe;Mk'*dNO?
	]RA96RN-]i^S(5YGR(eGdk,*>D1,KW;U,SGrC,ccjDFa<1Grs)s<c;Lj][l?<t%#W/:O/mSK&AL/b!
	pm:"kMP3iSrK2Wf-lA>9@?VXD$+Ut%Ddja8T5l3I*`IF:Wm5!2.TmXLbF/;CT=NriGEBi^o%AD@)je
	hn:Zf3?\5P&hQ?n*@s%RuL0Zj(^3o6`hdTVZ3?CaQYX'/CH30;b+eNSA\@b>`nbXgrh_sSF1s+@N7<
	HAeRqYgWjdW.I$;L5750$u`<3p5*CX5GpDb/of;`=7tH.uDW\ITT<0/J._)Nm&7-ALAp+u;M@_*C`;
	FkKCU67s=r**t[ZhKMm3@(!Nr!G:U!l*cCTDr7GW17dIbnHi4!/:l-YPe!l0\Aq7[]2Y=Dcgm+0aJg
	SKD,g2hUUXYpop9#eohD'*-$J08Si,?$RSUWiS/c+rd/0E[)Z<FJ!aAHdE,XGk1-2cJoC"Rl%k`.R4
	j"3'a^78\$N32M*lC(Gie?Uf=iaMO2)ci2:B-:G.B#G(Sc2q,M*rQ83L2dl73[jB7ZrP480ehe8:%Y
	'Q]jWE]=c?PrH#,+p??e%q?7i.g\,E,^n59eYb,FdY;C:PAuI\jlD<P1$/,])X+;7>s.8ku:CeEICE
	C.d8lZZ\_#>np/8Sc;I$>G^musccnks#MDX%IN)_?LM>0J93(dfd6/DW]4bfe@hBkiaGJKs5m>jq9e
	hs;<+K!DkW"6[g;:a\>h&aYWm\Hn8f+U:)T?kjZ,HjU97R0?eOFM(7[<l*oTT>H#7P]*$=mVH:#!dR
	WP)onsV7WUiTf5nGS2SE2Uco0[$ddjV</&6-,%uepZCs1GrRK8rIV3DR3)=bWMMdX[<*dV#?MprF/1
	@k-FQH)1k$M(\i*QLk`iOW\QQj:>I4*6KHq.+pM*nI2K>chBrPmY%g`!ZL0qu.$?Z0(ds"UE@PmRM[
	/hW,lo\(JCu^KnA@2-9rhR5fO.k8jcI7R)"];,q8q;,rr!YpOf*nBQg*(015McDs?SG]X#Dm::[DWk
	X#7PH*KM(Oc=4kuZ_3A&ItcY.l,^:\%4_,SGrC,^Cer6m>Ke,S+IK80j(TcA3qL/9Tc1Wp5G]mo=LO
	#$DgrKA\i1c/;O\F7;LC1pEke`8)c+_>XX2@$g:"oajcJ(FP+@KQRO6`FTjUlf0)AYNkT#_o)9/l`X
	?3?\VZt"Q#TE*.s8APh;^H@f"?]R07Sio[C-VKDa53ni8Mf!?7PHNBOiEcZ,CoQ?DcZ<p8H-6QZ7#M
	,c7A7LAn!+R#9F,*.";`c=.tA!rj&9T1j%/8VGACSrK#qeVJ:S2+!L%b9ogV']j^R^Y1pG&Ih"d)n=
	T/OR2*nk]9Gq1>.Urq:IX[P8-YZ1>H$4kq^.jD41[3G_N!a+ZR[*Juo7:G>^ZNnj<qa#LakT==PWbZ
	ioDopV>>_"K@=B4F0_Qh4kRG6<!_nO(Ga:Jq/'2dD@:5f7<K+)3Cd=KN()+\`FC)')*47(\2#hpScY
	S.<P;WM@c_gP?79A#fO[YCg!8ri5^mHM>B3<41]C=eoj"l%Xj?MaSc:Ih9^h=X4W:@O-4IMaSadN+B
	'b5L(P#G<I"laua+5hJj]`gaO?<e3*Tooo-bK>YKc_\TJJ,2YeZr9&NMenOdEr\9![N(`&,VQQo%Pp
	DmDUhsMk1B!"gR[3kS\L;_=Ui)rXoZqVi,Rh\lh&s`ro`G7\Dl`mJ_R.>>3%'FF,^eoZqY/HlD(;U>
	RY+hL4r`_!!LV[\TVgBaQWY'N'q;6XfH7`kPb0QoUDuKW:"3W.;X\\cK>o=R192N*Sj&6^ca2PT2QA
	?Q:bbfB>X?8W<r?e[]Xb-9Yoh"MJPfG](&9E3g%a$5tlf(fKZVJ4)N$d,$PCl^PS8Vd'#(0/`1.FM:
	91SAJ[RNeOnM%auFlL\)Xi]E&c#Z+pbNiQ=ZHW10^<e``IpfRs*nr=hK+ECk!mGL6%H$]162[=I8Xt
	4/E^J;Vb)@D/6Vl"3$'&7-(fL$!%I<M77usVFnnW,Ep$N4(OmOFFI'\fBnYuQ$,i=hT,*=9CP)$>6,
	SJ'enk^*Y7%tN4?)Gh,'>D,N(2Mi/6[d$ch0V:IS+h<"HMu*?!>S8g?g`O_ZFU7cRu?2pId.441V<n
	+@Fnf[C9s.igpcNG<IaAU?s!Y]nm1s?FnYID6_,sJlnB>PMl?@g[C+I-@UXG;1T&8qq_NI9]7&]64?
	J2C=iAZKe0At4K4E/+E4r.7i/A*MbZ%5Cr2D:+I=<3g,&42eq^+$rikID5DZgtu7NX">%]Iu!n`"X/
	lc2Ph/m$+G9g&J6l8tp&127W7E3*'^#BqURUn`KV44J1&9t_k%%eY)l9^NJ9Y*521TQA>RYg1pK?>X
	*,>Si=?A<>Ka[A+RO9qs7US&T/GS6&)HLO@;b^Fui#HsXtUh1Mk?bTWNMZ\eA;L7!I_`m\ba*03j'R
	k<B6/?afBQd`9C\,@99H\/sUp6hZ4#IK<a4-]c:9-Vi^[>Oj!r"R`7>CZ;dWifEC9gb8[p2hik5Ee#
	lcV<t)=X4W:@O-4IMaSadN$JpFO[paTOj8b3s"#Y]i$5D6_8roRo]Fl?j"aW$kO@6t<WsO61J`D=!m
	f#2O9;_h&,t-Z)Z2)mW@)!bj*CJ\ptGJ7+<G99<cteW`]Z,5hs'm40m+i=6hN>S;p3)AR65pCDl%D*
	Adcgu^$L[M)CDVR2o87m2hu[%/aRP4=QCB3(=-#Yf=9-Jq_:6m\MB0$AQfGr2Of9Df-]YDP;g$@3=g
	S-%ZnN^f$,61490H(2@,s6Bc2-f"/IYQfGoo+*3XrY2Q>#o2F]lJ*U?`6aLC#:5Pp\F#6s+#FX^Cf[
	hi:U-aS-"L,$%mS6)R(CF3iFqZ'eU2SC&C;@c$bY)u$LBN*r66L0q"k.6TKnL4"IVi5?9,JQ$_[rWr
	6,""@H/JmG]eA63%\cDXuCWKksCbpCpjWiR(5372g:/7jY=sn&(MVuc3b0-BK_nA1E!5<s[/)GkBeo
	6U(3QcZF/\7E9d`9](4j\M<Dos8d8/*;j6WkZIM..`U.#UJ;;2fVJR51\Lef/!pR3Xc>i$^@+46=A[
	[`Kb>EWYTPW<(TAnDOUO]k-XAWc$+Va4K`bi1!2US#X5E0>+Zp:HheaI!IP=R/egt_4c8;FHU^)Z(&
	gH7LZ0&9YJURZ8ca/Sko.jr6&A+,dbf&"7.S&TFb7]Eh$q'aR)%b+)9l)9r5\le&906#&GGo&<dp<6
	fGH>h=fIBC="F,fJniFm>WDGemTL24lkN>NTDRh_8g]"d[UP+`q_8+H8b%[*&fY20@m('Sn!<<hUi3
	B^N(#+gpcpn%pKRL<im.gF,mQ7Eu*r"j*HtlnLhbQSpLtCY6,-ODDuQAO\`M'%_/N6)&*\U,YX<Wef
	c,WP;4FD_V1klN](Gp]C\ib>:7$C7H`DriSOLS6/;A9PWbR\_91pfE)#L3327AS]?l1GZ$Rkh/ps;_
	5VN`'G?gs/Q"=4p;@1t#=9fZB]JqZ>^+"t.,#O:E%qUko,`7`FTe$h56o!,2B$+bLU!1s,$^jbB70`
	DQ6%XE(E<[pLXG'+.]/9QmrMJKMCK40$!&si'&&,"-EYFiX\Y3e<h6FGfqBNcF,#rQl*8).1A(YFV]
	[@#_VEU`ch?GoT;-*,oAJ>+5^'@Zo\*&)(B-!VMY5S"ZOnJ:0HW0!.-I:qB,lF#_gP)/Z?bHF\mA9o
	%R%QQTX,UmU9g7764b6l)]4[7KX,S:[2R<Sac]EA$=bP*[;o)_PD%!l49iiR?UdS-Z4uK$K]*&$LFR
	TdXhMQ*[IHOV1IeNu4j+/,S0CGAt?b""OOMc%b2S>5uon?ers8=Qd;f6&^#6rQ,d9+7IN&:2Bgc.RU
	=R(+^M6Mt@`d*t(nC+2NRGD9=.EY^`-F%GM`0tK&dACT7Y.sX8b.LIrW<RPVGl?5CX+XS/B1+_t\/,
	6XVu5a/pl3/L6faT+h5BPc&\J3jkHFh%p2B!$5CW*?<SaTI@*C&^B9EaMi@,Ff_a`^k2s:t_4h<IUU
	\>3Y]o2_I8\QX36m>Ke,S+IK80j(TjIn+;M*s)H\kMonf^YAGA'hF!1R.(GdB?<&IbRU\`0SR8,do,
	mpU.2MX/]qRrcZrHWp4e6JaDOpg&"eJq6.U.qSb+?@GNUH&+Z!TOi;>9p"*ZGI(B?6-0'JsBTn7^ea
	[nbWr5`1>9-TO_g4LX-HbXojK>QmntLU/kkA*5fEY0_Q[IA&Ig,\3h0-huW_QA1`V^<%io<ftV<WiN
	qu]q@UPoTJU+9(7_["ngCgq7)6C$.6UO:h(@)m3(lN;!4%_gapIf+8ero\e1%`[9/Af]sKHu!M>g^J
	SKJ+O(Y>eKisY>FoXhg1ingL\kMfl5'QWr;<>0]g\F@.]#)G7=.EA>eeo&["cPp6_k`^#]EtrhXgIS
	T!AB[@O,k&<6:/.I3B<9qD,b*d@nfkRKfUKW7gBj5!9DE7Qf^CEe?,GBa5\4YGNBI$.-Gj#p,9#JC6
	b%4o-O@6@%aR/]Bt!98@@)mKV(pZoSjl:_`>Po&A,5XS'?U6kncWqUr+^L.Hnel]&/qfcQfj4*<Wb2
	C[Al/\VkkZlDfjI<GG,SJ'enk^*Y7%tMi*m,[h8/*;NbEU?62r/-?]5R!+<WQ:H(!*^T=Tf2V1cVoH
	L3V7N^SGV:nl;[^S`\VT(X<$M.uq8.eQ)Hn-1cqms8HG;Zi9n6%]]B_^'UZaa%!;;A-*grEWiS?:He
	R4)V)2H$2CSdn\I:erRU`BSZ4?XonBCU.:5',!5GR/_n0Y^Q:3cdH(0f/a/A2A<P>gIQht:uosar=^
	?ONgJE).G%:H0]g^S/ul@8^TNr+F[WS5)ua3(8L<P>(nRCRBHQ^d9M^7VsqE`Kk^%-L`a_jpbLn,B#
	\+)MV=s3UXCfqKO*Fq,QqD1uYQJ2Qinj5?<YmsJ0$%t=G#<IN\0nB,nTlZoXjCZH8iJLq[W^.&Rl[j
	^]lpu[pBHAlmF%m5dJL]@)<DlEMN55\/ULE>S09S<-ZoU`rC^0KoQ&\n>D^TZos]>8-,HH>,?fbB?7
	E)1&NfOk%O=>O_C(oJ82gAV"h^IQhhpnh7pD::9a<Q"^*r[c'1GS08>dru,<5jXkfa,oT%kAH%kWd=
	+C+&hin+8LGeP<JCmcd0IPgl''bSHSA7ZppqS#-P.$h"g+Zq5,\UM*s(]4Hr8YOXN\^LU'Gr'#dCS4
	\qIVOegdkORcLJb$@_>O"ZPLB8]4>Y'0VaWD4%8%=GCm[2/Q+rkn6j7Q,X\[KFOOpE>IQ%<$U&WXo-
	Q+/jMK(js%(@V"9;bGX7sgZ0B`Z8gG(r@*!T]0?-9<VKc*Sic23\(H'G]Iu^)"kR>%F%_aAZ#_ENVO
	q,5\U+]lC8Dr_<P?-WG'9Yc@!:-7on_@DPH*)5_35i"0Q1-NF$-.[\Mo3s^PO^#/h,^\eH?`H_D1,;
	4F:O4e]+XrU[#_((sgnM[PqHm^#<;!T=J[[BC??*@C%1dKeNGH-WU-$%td=-FNKoM-^Q/Z]g=a#5m?
	l;Z[mEk''Dt'O`=g!@*57>J===.UoM$B3l+dV14ma^CYgdc0CZTGhHk0ph7GB@!s?JVBbg*l8\*Jq5
	An49hK'alYsV<fqO;]fh8:4XdQdY:n"d_6IFMq]7k_(**R+:M]SF"-'>3KDXoAOsLZG'@Ubc,:Kfn5
	:1`El1.I,1!SD'n0X<BaICl0N')j5-^,*>D1,KW;U,SGrC,^Cer6m>KeFOlj87BL<bK7=!g9m?ZE2E
	%k>#F_K?9D4[Mf+p_)b$/g9^n+"/HtmX9r93BXOYboC`ipQ-OA4oRprY,^D>jW5_S<a)1NHbG(G%4,
	@u*8<'PF\Cq'@`G9/aW`q.jo"GP-UgoPIU[/k"9sVI=pge1:!:@c_O`$9">TJ7j-t0/=Ub'"A^r"?o
	%hlmJg9(tel$::\'5fRIZ]ARW'(458g`pV=!0.1>,e)j*-ge*a+kbhE6?OLYs>5d&)A7IZAaYL51L_
	.j3+n6D<d9)<OeWiO2q=PWtc*kh?nWrC'UJ#)@FG9U,IU?uIC--`P0i+2Hco,P9i'9Br)Bk#p'#2s-
	bX&*.hN*bh'=S$\K[6]a/#]O*fLV2'RY=h=>;gl?hVO]c8^/'hJ6fVu?.K=t)?S8u*fcA;'+5&THlM
	I2ADY5<fYQcjCX;T3trN`qdG;Ifn3la;$&F#SF(-Qb[)6AVM&oouJk)_qCZuJ<N00UVtIl-ED'eg)0
	7Ij/U,SGrC,^Cer6m>Ke,S+IK80j(Tc8nl666(T&:""dZYuUo"lnm'jXe.SYAq;m``AgfB0g6Q2!Db
	g8MlbYJ@UT<!4%C(c\D2X:2nKaVb'FtRWkAJZPobIb[*jVGZp9"ACZE)(qVdjM>0%J(pT<Z2[la\Go
	g]N(#J^87(k2]?Cf:p>1Je#*lNY/V]^6R9g&RM2ftfcjXPqqn>@?t'0!<T0!rTac^iaHjn%N1__M65
	NkO'hnGqk&TBdUh;E*gZmk,Qf:c`,$FHPLV0dD;8+)doG!5'`t`')*bK)L:8C`\-n(I("dErR*k'W;
	77@i0bSoE:3<M4LR7g"huAa!$D856pXf;6eJ7nT\HtG?@_Wi;A`W]U\Vjl]DCdV)R_@/\hWF7<i:R)
	Zs"<!:[_fK2W'R'qK3fKc=Sg21GdtF3goTKN.Lk5GU_coquh&1^[c6S[hp,PY!nn-8Cm&cY9VBQ=LV
	UjD=iY\7bS]K6!67;M<@>d%kiDnJaMWtd9Enp$[s1*"INk,V^?h)=n59i,SGrC,^Cer6m>Ke,S+IK8
	0j(Tc8nl^bUugK%d]ip>JtIXlbjm#qr"#U\^W5^_0sF]7HtYUk0jQq@m&hom1A_E.0i5@/R^b*51dn
	<BdDXjrleaJK<"BfhqPCX*uo$0(/20H$(Osf&WgdYL&LGod49-Q"_7>n#9Quhcc(62Sa4>bqTFOro-
	&A6d<Ttcdh^U%?l&Ft%E)d+#GXOHo[6SVX)0',pTX_2\4Iaf?CL%M4S%-&gi5kkoo]N^qT9bm,sUmq
	YH#0;7Lk0`'fioAC;ner"&lXLfV_fj!XegDNJo<F3@$/dZ5`c45(;rbWqr&8I%RDpA]elBN;"2Z!Z/
	cJM6iDtfHYS+=?kUEbP<i/b'6L%r@RFFMn$<ko/e"K[NXNbjZ=jS#n^&7bR?@Jb`Z>Ih8$XgV'X8n/
	mqtUSADUS4WLrXLO7KAiVo::a*"Jqn@[p9\rR,p-QRL[K_XDlc/<kFaMM:K1V$lC(PT@p/]pY/&f=C
	L[t;VTqKYZH.>pS<;2cb2AW]M/MNQtn//!e-1"'3;b)C`&*O)65"#eYBJE)=T4+5-n3#[C^7QS3%QA
	JNGfQTocp+a^kYUn)tjW%8SZG<2#'9?@(`L&"hiVEF*J+OUYVm]j4lF4NEQ`BpQ\#Hso^cAhZi7+_O
	\11^-J+m$,oC.qSI9tJ$M1n+Z,;\<B0OSa:$N+e`TH8q9bX:5U#&tDl<*M8c+"m^LG!j=6[ZnRl:Xh
	)_bn\$"Rln?;Lr*!0`nd;k#<Bs$.++mdi2t'pr\k)Z)'=>ne^Y_"8*^2&mFT/Z[8lRCaTHT+#f)Jn4
	P%E%LVZ^X_MA$\8Y"E-,'eP"3c:d:S'>@M6(QpmXkSko[;B]l[^!A/SpK:l$YJpQ/F[Y;qF2A-r\bt
	<IhW'n4mejs6QGrr_<s&M6EHEfN[ISm;RK0nbG1PMW-WFi\Ms7HLc*t\hZjQ:_0gZ?f`>Z^R)HBmaL
	jrE.iA_13(<cS1J)QcPns5nH)p^7J5nRWAou,6m'H2p<k^#@6m>Ke,S+IK80j(TjIn+;M*s)H=_Glf
	=4K>QQu[<aq7hpnj'S6qI`nd":](<A_k\OXqYe#t50Z.a7OKS1P>)Q::F!aM5mo6)=gmRG@HE@GcBR
	Sbc,dqMf<>4:WeX1g<V7lF`p`=O.I8.'d57?f[AUjE>qBF]ci##7d'*5H:T/SW*dhq@"f>uqjQ.qD4
	1DM'`3hA_=g-aeF9oW7Kp\J71Z4#L9>D=l!<HTN(g.%ae0Z-mI=rTJ%!c?B"tc9%hDbAS0>:]AgRjp
	8oq26e=UL(OWR=@h-e@&)J'ihn=pm'V<#5(TC)Z96?*R\#,<a,[\D_XNI03rdXi&5*fXqgoIIe#1lh
	e1]%eZc:OZ/dnb5j8\&F8699Ge,Ucjf$BT/0"*OQ!Y.TajBhCn7`(YG!#l"h&mKiMSC/<P4sV[MqF,
	ORCeL%]o\'?i#MW:X7p&kOTLj=pm$m`>.aSD\W#g?-P)5N1WqZjs4pG#1VD3#8UieFpa1TaMBrm6iu
	h=S-0MfT>0HVZ:H5R`CTPr(5YGR(eGdk,*>D1,FrtSbR1:mf$)pZWX"A*HPu=MnPdN%i.!pANI-em^
	Co:?bd'n?[<1uTRa_kpX+GPnajQW_ENJ^\r0YB'?D-SK.eW8a!P\KZ:]:l)?h*C\Wp5.!*+0=T!Lf=
	KGmMd;/EsssHT>Xrs7n=]<RpR:J%h]CW.0l.ZT@5rZ+?rM5JTGfq>l!N=))R'Y18V*SJhRiIV'>mFL
	S^mA'TY_[=MboM&LA-ihr2$R?ji0g/9R@BKrcIpM@c1h"&lPWVY)ai(<r1b5?,MK>"^V\>Dh,gj,cK
	lYB<\8[sNL'8Iso0AcP?o]r!8H<f!S&l*[t$1BYSHN>ce>+c25^*3<@e!+'REJ?I7>*oM@Q3!R%H3_
	7_1l+#Y(42J6@ak9XE\K_!1[slD'QG`01#IY<A!oB\fC>Vkn[B`QfOi0XWpUbE2'!P<ZgLWopZ`[b$
	br<[&*fO_,l+bApBi?qDp`<.T;<a_oDA[\@>Z#.9ntk1klU[Ucb^o+^+"t.,#O:E%qUko,`7`FTe$h
	56nskT@>IJ0,h0WW3m=BVn5.lTn&JQC\HA$ZotGcr<n4f1_fpCg;,nD</`mCJ<GOAqYg6YRNnuVW\,
	Ru:J.(smWHooHT^#\^SB.u:lB21X;DZ*K2V0W1q$cjVGUg*XHEpO?OkKTh,+.1*J+ISXrV%E2/QH`T
	"6Wrq_fug-nA[5kd[N5agMY%,cEDf^rlMqQ42uch)t:lX)38q8`-lP4a/(<jZN3j8^CQt0=:3*.b#e
	bllH%Z*P1[MK38"2OLG1)GD?/k5N4bmVM0s/5K+GOf?QkR7n8W@g`0`c;!PI&,W8Lj,m:!69],n[ne
	b<po'#tp,p0g3(*BjYjQEYhX,91ps,0]ZL&pWhAb1;qe^j]U[^j5<@i5NPaH"1W$*32#NoCXMug!RA
	Lp*mQ5eP-g!NRlhE=\cdl^"UL%7R#\4ZmgnXOi+kOn\r!Ts8!J3PLV^c-cIF8n!6iCibP]*%JTMQhF
	nY\G67+eD2r'&F7;Se,NNDoi!6`[PRVIQfAa`B7o[0C'65\ea72?d-O"+1nA2k=obBFAM1',`B1#H:
	9j`Z/)sc"Dj5Km#dr$BCM+"(Z/9rY%6m>Ke,S+IK80j(T/=h4tD\4YR6e"]EcIt<VU7MlkEQa'6F_T
	rAWh*E]T"stXBZu07i)TF5=@5IF".hUU+)[s-5';tu:M<O:9\#CX=C+6t9M88j1@d#;s"TKgJ"8Du1
	]QGtBMfU4'AMi;1LR(6LBm"h-h,I^*p<)q^NgcYPl_1ae%tr/nel97V(Sq/o67k+#$"Hb0qQ^=mp9"
	4J(YjBm^0dcFqh`ARgin#UjRDg#I6=Uc2D%mf3Na&WrM13IB&lE";@l7i*"@l!&siBGEIOUR<QAAeS
	,Q\gG.pGnHGT[))[9uFt#qU:r&IUH5l_U^#hb^5Pll(p"fKe;tX#hI+d;*N.p@SY#/m9mmS!=i7HPY
	pK]Yn%9%JeA.Q+f^N^doUDKt]lV8BHk#'uT5^i>S>$SBH3-Uk[le2trV*f`?qI%uJo&I3J(u*skf_7
	7ii>Q_66_-@=Ke2B2+oh3Jq6d2-U=S\XEQO"(Ftg@:)/EsaeFupj\,agGU)o@Bj[q2.@87F>p/tan:
	j&TDs7NP>a?Z@XNo*aio-:n$);BS)W]-!P'DkR8SSJH(917TR&aQ?-Mf""5b;X!p80j(TjIn+;M*s(
	]4Hr8YOXN])Qr.lKYYGiL]7(DE9_[5T$'/r0!N&nu_\63j^b;3&`\^=Ob%?tgO2;#q*8LbDVQk__=`
	lF"\Jc<`iF/A'2AfKIU>PWVi18B^p\kcBEoNHm5^gj)YJ=QN:$gDeE/obf\7_WFDs!CY5\=fhkAf8f
	^B]&#H3e,";\h[4L@GuSW.uE`UODY)f;X(B(3=WXplh_,j6c%V\2FNa>0VS7'e$,l[L1<I2N^X?:Z:
	n(>QFfd,Vc\SM(aWepdm^MQ%)a*"\"sA#OfJ'44E-;:'nQgb+RX\R/r)>Y)XE!]j=Ibe\P?PFTpVn4
	Ltj^rr5`%T)\[H^TZq=9>JnUB?6E6HoA_Qr>9=j_*'%.62+>!f6=r[[9B>1mg[4.;/'4&)IL&r@`2O
	i(T8>fkIu3IpK(23ps[a!DQjr'KZc$fr*6Z8[E61%TR[?>18$X?-DDIgdfDu,[)j,&inc+pM609U[J
	;XAg."Kem2"!d1[lC:e;oQW,L7Q`UI=nm_j$p:kZRg)U?Q-'Rl=j$PuD&/5%em'rPNm#ON_1XklPFi
	b[I&Y^As5L0Q:=YS$GR1'#dE4:_nmUU)6HCas)s='I-bO#+.rVoo,n$Q2=P:XFYqk*rSR?"7F`H"im
	U._(f/0?njeH?q`^dYb>eFI_`\30i]mPicj]c)[t,6^hucXi,O%blF#lcr&WqCYS#SF:`EAL-KP>OA
	MHPT'20laJVAC!e'(@6ak@utYZ8glq"WG^;YAU8@&A/)"r>cmK9%n=L]&o>lr7t12AIq.5Ig;c<Ia)
	5^8C2Vgk;\Ok.mjdSAd?C':?6Ijj-u-a9Uqp"m[8*AnNDZmaUiI22=%cI+>8srIoT[8)Z9YL0st7(L
	Tat,OEkOFk`;TUk@ur9[UJ*Lj\=&?8Wa0n#J?S*[pS_]BunjWVSuSqiRmSO=.WM&aqs,PF*F^a4fb(
	$>Oig!tuhhc?M=84Qe&,3%pcj\<4dY2B%eb9l"QU#YahKhZ$n^&!'QU_#]LsKOq4K`27CoC8dH'hKj
	Oq^[Ck:A`aQm/sa:HgF`>X^pJ+L?:9(u/tNSW'CR)*'jRNr''c]\rC#`,DU.5>eo1Z9N@(d")Yq3*B
	mA&>-J%nE%!$]@Ha'(lQ#E\Vd]i^Tj:aK$nF[kaJU&d>;,0YHf"$0,(5YGR(eGdk,*>D1,KW;U,SGr
	C,g.?[e0HYfm)7AQ*^BL,CuiIJ4IcXLlH=hUVUOI1R0^Quf-u3XjauT.2R08#3-(o,?<g$QfkoUT7b
	6OiHXsZFM1q?%d9u6^((jc06>"9FUEoVs8cDQ2-e:aMjkM3.V+#i)/PfX+!AEaQiG&8Shnce6U\&k4
	?Zuh/?`es#L,>K"Sh?fHcfXX-A50`6c/?cpo9mq)qIQj"VJt9;FrZ+]kD6T"d6Ha<&E)lu">U+7*98
	$QA,nammpCaOI,">8&9tjIH2HY)aMaH_@D1K=3AOK=H9'VbdNj>`i-e)!K(Tmk^a8XfcGc]/C:s_(\
	?uSH\s4,o5Q0llWd`!dr`RbVQ>nQk50c*h@;HsRes27Q),aLi7dhg#IW#hHg*8^D[g[^kb[[:0'R[s
	nb6%(3s7US8:X.i>]^_H(WkRUnbjDP@E;seo`&SS?R*T:UgtX81ImCbqLa[>^-3%nHH8E/)I`lS:S#
	A]B*]EG1*^cY,]\'%CajMa2QNIa+[o.t$\Qm$7o]0s5jli<,pqEWgA@7<0>qY/@*1]KpMQ>]bT>;l.
	`L";Be\/l1f()O<,SGrC,^Cer6m>Ke,S+IK80j(T/56@:XOk7'3Xt`2lI<Vdg,7$kW8i*W9.S(Kd&:
	%#p/+)>_-V(&D8%M'=-YS"n.fiuM-bRh%N+s>q.DE?'6su=#3]4=AMY\g8&f`UQiis9/mQOe[OE;N1
	MRk:8O!*U?V;%k1^IJfcE]oGk0+D3h<ZDSk(!B[^T..2TD`8"DkN$pU5YQ'0f]BSMDR$<lRmo&HMdt
	X3'@!b4R)Z9=9E=[\/Y0Vb\"XaQWE%V*:=tf9A\V/fn+F:jB6p9IauWE!+305i/E0U&)U4V,DRXG4Z
	0rXeZZ[gl_K"5SkubKH:X3#HASN!BnM6Qg"<0-_7L/WJU,m)"J>I]ht]<5^Z`T8V!8E@^BOL;KYLN.
	33sRU0c=Cs[R7,</#"O6dTRiUoB6bBj_-]kB$,.>qCq?:LRpK(l>diq\eSY%If1n[e\'t_CK19#\)T
	WlY0FJC(K\\ESYAdj$Y*LK_fI%qf/F%UNJn/+jWq*[EYdMK,`D/$HO_gRX&[YU*S7@$%p\nJEV'=WA
	oNe>o]'-).#0'_@VhooqPemF[nCf+of'/o^Fe*K#N#/k]5b$"PiK%CinIJ8Kp$j-&rB#]PWY1!,*=9
	CP)$>6,SJ'eQ:<uPFR1d4S)IZ'\47X7Xm.Zdfo_K>S=Q1!7+M0prLKrI[/fe&-uUq<Gm-Khf\[<dkk
	#e'de"0>c6ZPbhjW0:hmS@"#38q</Fk$,->^Kq%f6Pl:P60Q8!D@2WBXJtq["hC_$o_F6(Zkt"a6aZ
	iPe!jMD9VEe)6Mko-80TF_?^)HmtuG[G\qsBOJOoL&Ge*J!6lsr"fmDHI;oI2@Xo$Rh`R<Lh`=3hBL
	TWC(OklV]L[nF'sA3D?^%tVQl+\a5AT,!B,/`+6)+rPP=uWeUR,N+/o$OGG,Q+)de2Ug=pO74YVD%f
	0f!AHAK>F.,24%3=.<`dOk;:ZaUJBr57.DU?XuB_Z*SXGVR4ROkk=S^/XCXa4W!eXYJ]Y?bD#\E+oe
	Gl[HuK%`pf)8E1^U>JkkJZlQmLCMpg_e]fT3l[9:.U$@.-5!6R`3o=P"oph];Os/Wt+m"bH-KT>.aN
	%$D73ZbR2dG-jZ\s'PAQNm?/Bm#m!;hTLHSDmZ&m2SPFZ%!7jb5edY2\krna>\l$@)='``K,85J?s?
	<1Tg+I24sr*!bpa>`Z%q8U8e[<5'f>6m>Ku,S+IK80j(TjIn+;M*s(]'iEP$&5dAWLjl-o`5>/s>NI
	bn]3Vl(c)TXV\O4oRcg4X(rSRL!<L4?V6tQLLkIr.MbZDO_:Z^/cISnWS?N1pD=+"OA7lm$7:EIh)@
	OR8sL?-T9.=XTA0IM;O@nUIn<OCG?9`=SblDpdZIm;Xj9+bN@rhZNT`u:f4.K9=AkYq54:]?WZJ,B2
	ZJ4!0<LeI["m!sd9#c$YF49!Rp]jB6mrm4.i:(n\m^+?eTYm%B2_#\MdA!:;_`ch!dCGir':WuV5HB
	`aAc-HqO/:kVp4SVCL^#9/q^Yf9'T_fdY>h+?#jmT/En%OCDLHAk&SqOlR3ojAp(<2c8X425GT2%&P
	j=:u?dnTBRhb<51*?/>=qrjV\D_c[r_go0%..<X-ZU`Ws+`?&,`,WD;b1J&+6"WQr7JZ1Z*-\qbIXE
	1-^M!"0WdaGGA:MAh7_Hq/+2A^/EP#n$(Y:g<"@mX)\-EJ61<leZ@S#+f1pB^^=WDYK-Lgki[c"]Yc
	+toY@e-^&4aRfhHugrP1q.J<SpZp^PMu&,h=d/l;tZ&Up.eUh!o1OKosEfHFnui*Ag]:YQ$.l\&*?K
	u.>pS<;2cb2AW]M/MNQtn//!e-0p8BfoH2!t/ZnIuS,\!)8-<)?3N0tNrs_uk1G;c$O1u-)eW[L<e^
	#lI];dNtq:AUERQ#^geNjQ!bUC7j/]nmt)+Sl>^o'DqlD5sI\*JQ3Bdrg$%IKskob@)TC4Y(6)VDW5
	:d[1.I#,_jRcK+p%*Xd+;h)5&`o-Jurg/7CWrDJuiCsf:!PNsVc/?I8%d'[$i>eTmq[X)hoFaS\h#6
	ENY3HdJf[mDgQQ_prYk=dB(3&]Tb;_-;)@mI94`M>;meSPj+*kg0DtPRKHaSmElErAH].SWKHfl]!W
	d8Y+RC449%PjJ;qR(fPol%JFhY_T1roL/glQC`oAZ,/u<Xe_2gG)0VZ:43s-LoAK94=B,`6*3-J'6V
	MF&/bjXb!D9lt[sJEa-GnO<ft4Je(WA2,Tik\4;RL`->V#%:_@mkF3P^m`3/-i55EpGkWmL#qp?S%;
	+GD0t)*-hXD]ZN3?59L-u&9fej;=qNB$AICF(04d%+`IZ<d3(LHnD<U]f;pi9?QmjA_pR/=Qm,@fn2
	^\gH!?ZFQ&WqP/fnL,[QY3!3oO=]mNWCjlRMaSadN$JpFO[paTOlW2e&rB"2P4d9_q:QIFa14$WhKi
	71rDloOS33n<$=t@8GW@`%s7=VJ^l08Y\00+-0b<D[;Q_bKmaF;hF]+erkg;'2II^-r^Gop@%&;'Al
	GFD,n,59(K;LeJ_5jN40kQ>a1Q5YaS%f5in5mA_b_hB_SC]F.*.5<GJD\#(!J>/H^cbm2N1i4]D-#4
	q3h;h6=7q7`+e)q`$%-T_(]E.SFC&AhGo@K*MJRja*^fD:A/W&fh$iDtg6=*#@8;4@s74r+Bs@L,(g
	(k=G0I(D.F^Q[/`]qsqCGbHB0HGOW_*$?7MbG'Cs"K*9<IU8!g!.E'm?[AB\d\n3mFKp%-.!;R@6iT
	]4;Q/8(?"KNNtaM@I@o4VW/-sUShS5%@3Q]N1*3RpWN1CE_C#AnXbBHs+pmW#/\E'8PnhCZ]-i.ajK
	tr'A']_ld2>QF2%&nrg\=1DV^0D8I+_%rhCemhWPg5he^%-XIL@tG(SQoSH[+oAW]M/MNQtn//!e-0
	p4Y`73[jB7QTj/RDYDo1g&_FMgegZPEWbVl3>3-oG.)Z5Nn`#:-dTlfP?9;e3G,RK7,mj5c_iB1`_$
	:/]7Z,jb4C8*)LM9"Hm&p\LrKdC")8'>TkgcRi&M@J<r-[_.nrd]Xg8DaC.%f%Su<O^4Y>9pMW>mmd
	5A:&DP]90U9Sa8<Q2CV]=I-,!=R3kPX''=go@.WdPi%"P5-]N#`_F(-P*FD:9n8q=/+F7rID90b)"m
	8eOqlBPq[NI*EZ_+G6'Dn.+M=:JW4mq+,,0Wb7A:"(CYBO/i'.D?Gg(RM_)Qf>Xk"%J1pfr*Q/:`*'
	[94VG=?FA;@sTS:JQ.\\I1cHosQPbA];Yqj8`QTC@L:AGXm%*m\NiSLP2DntDRa&P;"^Y1d@-ooTDg
	jc_Rofh3<cU\uAOsM%RmjiPifHb'M%U0Q4YV1@5/.!Re+M!%r#RQ.e80GGLJZrCf3,Fom^^K!.`\s,
	oak"2MN20U&ApWq"msj6doJtC@k!ZLi3:HIjX&aB9='nsW;s.4X5OT1<B]dBjJPl:cIIG78h5"Q,;=
	;[q%G-)@!N\NGi#8hHi-JG9K?kH>4eZYXH6F=n!q(I3$da[51bqbZj8>dr&$DMD(k,W0S[(d3&g^)S
	.#UJ;;1^'OZ:H5R,tM[=.8pYVEf#;-ZJ`]u;0Z&u^lPL%!?W:(+/kGJ%l/P7\(S)%hRe1lr3O$("TN
	N=#BfDGMp/!59\Yf0@51$)Qmi[^$n4?)r7"3fp66q?&RWi1-L?d?NiDk/ApXrfo?g_%#(5L4kZRY]G
	MkFWWs6A\'QH\hK+DiP_Uk=C#Cl*</<6PFI'VdbaOG+X_=T>MN#O+2h>@[`jGc)@fD#Fi7j#TjgScK
	+)YX\9MHOJZ[UIK8`n"i:e'*F8hL?6k5lU>@?pE*WgLkF"Trq`m9KB'3F%;$8Z\SM;_1T>-8f-bRjR
	Yp/6]1;kI(I6i\n:a*WDLOr`oM>UHbIPQ/_/)mc@o-2?JFODAkj@koM!?GF-5/hI-<09VUU[qAk:s+
	q0_^d:=l*'j#]4XNSG/q_`@*;@K0UkDJ&4qQ0+%cLjCbT$s<<SlA,33.po1>JBij[cr/!Ult8S(V^r
	I;6j]#-as)s=PT\)B//!e-$.:WFPQ>0n%/GJ]_iCk0<7e0#?p0cXA7DWai6SeFr/B_7<,%j"Tp-pOk
	lp88qCCHUT=8_EhGp`[hIkob\Lc`4.>rSKS7tWGg1'W+.e4]d$k]I^.7;e2@]g%?n6%[u+*O=ZYHaY
	84;`>Po\TQ9FaiDX?e=ru5)=#jZVEM%=WB]@N6aY9$JE%]Z-`"qjt-&=C)'F1igRLAc#7*]F*HPF_U
	d8qh6TWFl?_8uGY=IZHGo6Xe;r"NPMq]!I*'8G*bg5j[p<h!Z0;%[3G4")1:dhIPOEjE!PJ!N"5om;
	X,s%AFi]5Siu6"+SEYUr(j%IW<YPAVkHV]d?o93j1LH?iPUdJnZ0g)o%s.6j'G2=,n@^5\n_H%ua=B
	uu-jKtGbbN?K:!YNgfg(<pmI\VeY)aR=GcohYk8#:pP[dIH85.Wi7B9U`nFc].Giq0,YLdY[Y<O7eF
	bUt=ACC+2Lt3GmBQfgiGKM+l8<b7=U+?q66j]#-as)s=PTZN:VAtda;5M*<6AIO4*rXcL)0h&)oB<6
	P9OoZ/b`oYD=kDiRgN_+@AGA24=Cb,)7n&rtCL_0HK3/u\4-MXmR0AKW.I5R/!bhBl&+mL2>QOX5XZ
	@;.RelfU-n!VbJ7Addr!#Ae!!r5=2u;?cd;Q8a:Zsh4_7)O6fBk&4=giunj@j3Y][aP*^J8$pc[^TF
	=HjOS==.rG1"I.HJ!mISn87s%bmfn=5ZnQ$JJ7KNVF6_*QTa>nM[bX&b7^/;/EsBr]S4l<i2;f]d-W
	L3j4o([-[4j%`k_S[jR$O93o:F$jH3MCGK$Vmb`q'.O!5'@=?_Ol1FP5X3M_%]W@@>l\;^Bu`0A`!R
	$2?HrPFrb'Re#kjF-1g%5YlaSua&MqqtoDT?PQ3s.6]jq@iE+TRDP'rb5B=C!&LXGjsl3:g\A<96KX
	4pb"XMiZgl8gbJKq49La.AW]M/8s!R\(5YGR"A'A?O[p`iONogajpqa=nJNg\d>WdND`JIpd$YBr@^
	PcSG]*W]`+$`"oNQZpHLYk0!q5*:;.MX[\%mjE'KDOWq$)_+f2$hpasHPb<FZll'X:_.fs7^anS8B%
	AZ(A\2;o^$QbYP^!k)/?%bNHa1H,GT[4.<UbO!aOa8bgZ]"\"r0\jige'gG[!$D856pXf(A"7_31TA
	3?,N?7'6k#;8V?=u"2CnoM*qbZeWRi#m`=$mke+MR-\->]-_0l2$Gb7Q6Ef[Mko>Iptb4%Q?'(Ztrq
	i5Y::=(h)[0G5VQFLI@!U".J2"pa1n)ISOUZh:b"q73i@\oDq2<'n^Po_*PH6J@$K*ZN>"^niS#BLO
	,2XFB!\.O,spUfM2-QdXNs.s^i*hLDk<fA5Gmued*6U#;Zl%]:'p\5'eqO8iCFb\31jd5"O%/fu)'r
	*[GoQ"/X1$'On[FFW;Ss[=hEa?mhW[fuqcB0#HB2WcJ//!e-$'Hj^,*>E\+N^?/&rB!_d[BRO7pae^
	%DC-rIAkUtpcV:7e[h=\ma1Y)4RrXOb*V=\R9*(@d]gQBqTIg*X2^:,E-r`eDn_%ZlO2XNaoT[)*CW
	c7dKl62`!!`[;\^uMLQ9'sVVZ;Q]O%)J4=Kb^gG\/0YSiqSX'l7d\6ajK/X8&_%3Ib0lr@G+2uW`fF
	oBd=s+IP1ql-2r*P=6RIb1CISM^.og$e98561pnT/qP=m*!]W4,tNSa-XI..U@Pfe+`/h*l)b)(%GU
	r9jZZ&`L(:Ni.k<D4BG?XaB08t_-F\E"kW(oV-Joejf<e$';*_GOi-\%jt6f>on^Sf'XMVe+)4Wl0j
	1HcDk9>B-i=PI*79&p4"U(JVc"B'(@"o0rs?nFWJ"b?%#h_^I5M+QB%%p;bfnf!rdco#/G1U%9UqkY
	Mn$*GD8q@_kk]o&nN-rOQt<&"*&)AEb$Gb=jj4)G[YaI"o\:ja=aiRns,3K_32aM_TA1lR6m>K[,`A
	s!,SDCoZ7(W!,#Nr6k*\!dhPP@%H%?%72:BRl2.A8@XF$PA-Qe*SoR[BoDp8QHlr4X7W.,*>a\q%h^
	\`ENKi=30@6YY!jW2*qSnp'+$$tC/Gnsrr.r`0TI-r=eJ+YmIlM:b[i4&W>6EmI:n[O\5E?'M4Ku@C
	/as0q60gl*P3i;%W9,6^mfS<BFQGCG*$K.N-^>gkgIF%(@U?g?oVpV+=F7cH8>,r,3R!5J^S.?/!lq
	-8VCj7[\TIj$D8B8^F)BT*CreE^eJZ`q%rFZu1P<[U*.Y?n,2[4B;q[deE(D\G1[fa?lo-bIMRstY_
	H05<jjgH6qWp<IYT<IMUB@C8eei&ICU@E>7l7^bD-heUMZ<=Vf(LOEZkO*rhfT/NdGDCS3V?IIq\%o
	^V`-2%KR*RFuqpi:WlrUoZA(e=qfCM3%XJrsD5"3-7`HS>sM#Bj9I;cL^]Yl+7I[.S8a6P]$R76n#Y
	MOisM`$q&d^9GO]Ks)16Tjq,e#s0Z\PD#B`C[_m`O26dj1Ed[i@<sI)G\\+V<l[WO]c_&//!e-$'Hj
	^,*>E\+N^?/&rB!_d[=ajPacJd:^)'E1TB8;-4<;//J)u>+4Knf_sf<tfEr*Gk(%fiS\r$&HMmZmIL
	V+^jVK-Hi2W.C0#kF352=R+R-C/KIR)M+oB9Q5:Dj`t4;Z6<lKu?cli6`7Gj%*$H`O<MURQCC:aUf\
	H,24Hk/JCHC\.mp,sQ*'M0U&Ti'L_A4G*QfM]V$YY<MPh?,,K$0@;XG(+[-/^6p9sBX<HFdj97V2f/
	Sj>Z_'7qpsB6V!A7,`8!8m#Q!<7\l%&qSVrGkCG'joY"r'%cf9es,-N'k?QN=U6eA.@niLL"OcLNuH
	iN/"s/PDRr9'-Gru&sE=:bFJAedHR)+=1SR\;9p1%^pHOKR@$CqtDL(,=3X:%7RXh!p3':K;"K?!G7
	;:TVQ"1ZX[:e1j0_#022\`Rj="a#057KD=ou56"&Wa'$(3QcAWU(AY%1jM`/W_=?qTL@=//lG'7<TA
	Goa;V0r=i46Jf]g^NdK/g%+!3Tu.60A\^H],6"\Mn;K[ZN>M%KnDoG+fuq/2d:[6Y*JU>FeX5S[(d3
	&g^)S.#UJ;;1^'OZ:H5R,tM[?.4b,BimfZZT+?+/Ftf`+,'e*T0WE13@)T(!b^m,&@gW<KZPEr<Zjp
	^,SNLp(]^Hq\qOt']+aC7q!oM5!^^=!sc;"ULc_J]teH`No;&rM?KJA)6?57OC#N[:V2'4*Xgsr$VZ
	Xmj?/=:A.+U;WbT4JObXaf_5pf2*P*6XJ^ki&se)n9ELRCNpk(XL@"FrOha1WR;:n%'5s!s_?4+4m'
	-Y-("b%q!qr:UpW(&MVRK>L8#m_QE<p&*DgM4aQ:D]&%c>m.0RSR"l>2\<^lH**6kXS8mnAN6N1@_k
	!LM*`Xmq8qD-QHNM7%mrhrST:H)Y<t3=9#Uu7tVJF)doj\WmbiE`&[5sQ&:o,^]roT@#2FG1NqMVl/
	2m$AhCHhuPH?g1d\P9WYDM\80PdA%&(c_;i;rI3KBk1IR\9YilYFu6`\OeoEYoCd(.C>0$g8"T90V\
	$iaZ\:2ShlY;R*S5:kGtiP!aV:cUS@P:R%eFm^Z8-m,SGqH,[$@#,*=9>P!rM!&r@6s1X;5uR/46'c
	>n`aF=:)<Vef;o[OD`gX]%BUlaRJ^aeQnl$H"4CEHr*HWEKJ_I*ml2e,7e7qfJCb#_-_R5[H`AIJcd
	&qSa%*cVTY.R7$A>..8>agGLGS2J1i$AR&&jJMIr8Q[,&Q8rqSZqr$;%4bS)W3TLpBPbHlHJId5$p4
	md=aX/_!;A%-U;$FT#+2g'gJb+>RZ4?"HVm-+:4PH,bpGr_Bp2eNin0@B_Jh3%>p-#SE+5M&Ra*#Qm
	W*QW,]+9;"3.UOS7=:C_##:`3JX]jiA@B^LfM?l-\I+4d,nQ\CS!XF:O0E/12)r<-LtlNnHKt`VD><
	aOTnI%.:V@Vr<QY?gKE()C,C;I=cR0W0@(9\a>ZXuh)n\/l,Emdi/Q=nAm[U'4RT[KE%NgJp]@"Xtq
	aQ_4dJOlb[ge[%G"i0g^GV)@IXN8dp3)8YR^RoT$cBofVj\H,`l,+jd[2O`=AQrF;-"4hMO4ak)c3?
	:Es>ZA\Pj9#7%sfU(1iV!,YF//;&5!VU'0_>1M)2dRV]B2`66km?q*d^i,fuO2\t&97JRIX:Ek]W<s
	0$`p>aNZ#6+<1/?kfuSqCl4]FabRLG3<tL-bT;ng^NI#9ES[&.mTU32ZhS8qC9J!+Rq??VGBt9^^<K
	rQqd26%<6Oig]TZ9k"A*YquYs>&AfUAbt$Eg@k$m$a.'CfD-!@.-f`sb`E$'3RNJ3aDi7PJG5%`P39
	3.D0GB#Dfg4eI&$?YfP?C#6W=8=iV`LZk[ic<920Y@(Jg0S3(NS(`\R]AK=kLIU9Irb7bb_dP_lZ;1
	sLNHMB%m6(eNS392TUsl>:2qi7D!:Fb[&M\;BZLXq0,94f2(No!:7WSEkP?o/8:YpD/O'0![ZJTD4G
	jf83kh(u*Ok19>]eJM4W(`uYCDp1LKrIHa2QV%phu]Qt8c^J_oI>?,u-j5>GD=^poc1S2e:mfjacjg
	f)ae#d"@ECSo\<XS:Qcg\'<gaS.L,#Nq;Mm>l!&g^)S.#UJ;;1`o0R;uBc77:s6&`1;AEL`jDE[O0q
	$oC\h]af<q>L_EP)?=^HA'QDj2T"r+Z6g&%_scT'GWmm4NuS<VA+nDS"N+u`NmiQ1$!ILCj(<=VD]E
	2cI@>pF8*3T*EYFcr@eM%qk56J%&:\'!p(E")ROS/q?UIkE+qEHa1!Y?T9tG53i2ZSi>V^0T=Q[_$g
	7_.i6Y=UP*Fg]0I]?j2c./S)FWE?t'6bt*_[_Zup>>M)mFs`l%G.PnS=75NOKp<:2^0kMIVlImDm^c
	2I6_V8c=.SC-JYUPB#Ij3S!7Ird^,5T4TeNFmD.$Pg6D30-jNmDA4WT1Eb2"(F1=-f*3S7T"n#`mB0
	7K_aIX`n^DGfe!S%suiV<P#_s(=La^b,6S9$-.+&F#qoj"\/rl7NK*HlgX<nP4^bNpA#glCn%^banm
	N]^PK.Cq_!%e?/d9HfI.3/rB;Kei5/%Jl($R?62QMaSadJg?8[80efo8?sY%6m>K[FQSuHrDGkY+a[
	YV`'(%La@gYcE'l_)4m4:1fE7H[*J9,eOYW.Qb!&i9(snBYn2'Jr$3iOR!Zj:f"`'\lJo$)kANgN`:
	l[g_TB-^"CV%HmHn[bH=Wt'"\BEGsN0sWeG3(/+mpB[gDko*_<<lk=l8WsNjshQ=^/,!:IrI?VgSJ\
	jcSZ4&DE<;7&\L(l^2h\8^FI5fErtMf>pc0pq/]j,2:njZF_1lonL_lcBf%6-JoZ>;#&t]":Ju@Z%P
	6/)9]=1qq3T3M*fuLJm,1tI3anldk3IBh0"=)V>I0rm9X"`+k#;BAYpf&eoYFj^RbKeiSY@YFMlrKE
	4M8JER)+"okJ5I1P@2E@ja_]BBB%=D`8lP/A*RjM:I?>=GLO+4<[XeaIVUN[fY%H-lG>6BZBN1M?a[
	\6Q&4gs3IZ#Uhu.""j"(m`SXc39c?7=KkAFO[rFGME7\pe^1cS3m4(XOF,YF//;&5!VU'+%'AW]M/8
	s%=X;[toDWTk\u>A$_TX1)D*%^J](cb2I:/j9.2#[6;s9S(YMWo,s9)Jo&&a+(8X-[13>^?DDsdIjr
	+?AS?qaQe3R5D!\&685:U"cQBfLj`q"mp%n@2>L-!Qe<M4*1NIH_>X5?!?AQ,/:uNIS7V9GHISRH>-
	b-T1<)+1%CW3if;#2CKnVSLp,9_\c^=cSDqDhi4R-ofD1Sf"jY>oF6"GLF.=8O,"lm5p0^;f`L^;H(
	>d)G@)jF&o!-8Pn0\4r'3:bE-Z@-M24Ho9saG68(`'nd.6D%!I`"k/ekt[_sO%Ii*YH-n,4Ync:0\P
	+!I"mlPiXn[=RI>@8D>bB?Db,9dm6&B^-s4aCp($1Vf,*p<JDphODCQp8G72XHVB1@**Qu_9d=C[]h
	KQ*)pY:J(jDYIXaajP$e+K^RY17P6A*[l2R<fQYqL"7Z_mS!\_])5H@+g`$]XR0851:9f0K-,TkGgB
	82kDYDS[(d3&g^)S.#UJ;;1^'OZ:H5R,tLKFGF&1<O)g=l>.Yf``cBP22LMUK`GaKI&&EmGC*'p^Pr
	cRn<f/Y@e)]!MaD9Qr2Ql:C:H8[Z<\'/9ADb'0T'-Phn9/)Es2oOps)_LC"5_6q#@&ghmQJ-f[1+"c
	8#jUO?!=pIf@<=ZVL0<X^\n>[<MKo0hW[DQ6d0hu(:.Ul^kdB>1&4q`HMWb:fc`9@E[h:bmM+44Hf]
	RP%h*dW#[$S;qf,qA$D6GU@+fs20Q`qUc'eN<^-?oFf>_;Vi6-k-3BRsa5B$:GE#h19lb*u:bJ2?ZA
	Epd?7,bH+(gYnSooPe)F?OuDSEm>HpB08h;!%u>WVMaFT+*lerUCb1s5"sFYGH3P`llH*T)'>=;g1B
	FUTUfRrd%jo#g6"$O6CmHK3iqLs78a&IK&`HfY35YVEKOo4f'VK07/SObd+FAo_gNsb*'2IY,KsEYo
	_5ccIr2$3#3TG;d"L6m80u]KfQDcb,A/]O[p`iN+>d$M+"'@8JYm"80gfhC__!K/,=[_\+7kraU]>4
	^i>AU!;AMK`(t'5a@kp1@$E:qP[tF=Mp.tnO7X+C*/#tcZj=shlZ$n2M)FUArR.$b>:kqd2R_T+*%Z
	&0#!B,>ru!NS2ne/j]&%JXMfjG](2PBtTR:AW?Iu1:i*9Kp&.<8P%l_eG+El'opC-',&Y5;F@&IFBq
	lY;To"]GAMrU[EdILP*Etp_Vb#?T;G;go\+[c(E*b@OR2W^#oj8,a!LqQ\mD&i1U^8F]Q;fC*B.<k0
	Va+&3E*;8%IBlN.#fr/(t)u_CpX/:<n3TY%8pW;U31lVI&S&$&V(7nb&Q/U9<VhlYUKjDFkK?,i/Ig
	_XLU-.Z87=8H3qsb[X.c_LTErN+^IJg@"a#:!&Nm0M&4hHqG;OL$%ouRklNjV^"ourQ\6c3">ek@2n
	AT.q.06_g*Hb+[t>FpW;2hN@Hf.Nlf\4q64<XR1BjA&i'&r@5H=d2?!OXNMY79LlKM%V)'OX#5F$j'
	0IojkB8<lHt.5rA,$oI#\C4(;eC9R6:JqHU.*Feu8<*;GHH/MPcP'&L7tpg_rg+6j6biOuc7\BLrSo
	m``cAS+2U\gZ%C,MqSpO*f^-Qg=L;[p6'$g[;l0nnZVD9uZ%j5tIU)(i6QJ^T$\mLXM\_gfLUJ6j`l
	^m:M9HED4##llq5.n#2/:;Kf8P/mPS'/&3BY*<b"A7iBke@aH,7oC1BUG[2gHcCKj&mc!b#>r$c2i*
	MA0AG"Noi+Fa..EqD*N0ms2iuT2NM`()cQhMqM5>;&>JO(.rr&X_A3HrHdi`n-1iP"=cngg`jgN8ua
	a;Qu6OD4<h[s_*)I?]@("j#.0^uHSLZ)>*cmoM]6hZRJEELlQfL<ohf%!"A*.TdcNDR`BlQi?hmo_K
	>/o.ulR8'jbJf4,?VqLSP54+jdN4SsPTaN%]9='W;cG;Pdqrgm6[PXQdY-pa"b=X4W:&gUVE73[jB6
	*_ppU!$4J.I++U4i\8nONEOKHL8::FR?YI:Zq/U:=m#rQqOkX%OiVdhad\1h!?\9IH'=*>sE>tkB/q
	V7ilQK%E?npmE6_^`1@$WW]/l]0%)jA$JbP(++d;a^3eb;CNg@n+8n4Bq).)1/<(hej$`!jXpaTWAe
	>jIHC=&S3HE&@)0jt8lt`KUh1r@3^s<X,HX`G6iS/7c-U,.1o0sT<.Nfd,n"!X6(Nja)^/6gV5gc8'
	Qp("r:RAr[IEG"q>$mlaRQ\+Dg(,uEp($[`llB[j*"q"+4d[nc>1!)&UL;bl](0UQjnUYRA$(;uR?:
	o?;lNfZ8aXmt;`P8Hr5J-AO$)WV5q<&p;a2PIR_ng(d@br@%9t7gmA%6V[K,0tk5^N^gJ6g,]_RWg#
	32M<Q^#2]pPUoC%Vs[mcZt_W4j(5$biAM"hrmPBR@c"V-'k8[\/o\1ZOZ)15NTsS,*>FgN(FdrO[p`
	iOCV3(M+"'@ac8CT+K!@Z@TYOndB9Eu(r$)Y21@.B<T)'*7=DQ,XdfI.D9Od-;-"T<]rMLms7#f)F?
	Q&tf=q.]pZoCfK?%qGqGpm?)$X$JM1q5daFSKg@+e9`^[mIuJO=kJn%kCJriX#d[85J]FqK,Tlm%7#
	,J2V=<pQ4;a5m/U*pf'!M+mV,F8n1DS5]%d(@B-dIkg\X@iK;Zm+!=eH$BP;n`'6)i4Wt]6&0p@Iqg
	&&4g]P1V?7a7eKZa,1b%dR8&>+)ojGqUZB`&'cggSZ*F8$!4iltCmZF3uj\I71cP\1UOkD/;`K#f<`
	k2afE$da>n0hp3Kfo"mEBGb_q&SD+^\?/8le:gc3J$WDGJ^ZU*VZT'[MPo+B<??\Y,?(0lhZ0&_4#S
	<O3`-k9n0$USs*"02Zt-Co+:]?5?G(fWF[Q5mnk]kf*`6RkoK7o2i3CS$^=@]-dSY0R',;)bDo%;&r
	B"h7C">"6m>K[,`As!,SDCo?(hT[1Iq#:p>Ta+i$4M,.'F`sNne=-%<dK9<=4!W:'SGaQp*)YkkFP'
	njud<SeL;%7+[bTjRYS/cp-dkTguhjlg]+*b(ZPTZ$X>[Nl0^U0X#:2@t)\'IneN"pOQ\$ipUd:F\p
	,`QW)i2=_`%ldVn))b>lM@2-ge%j@/Iqa;/^4Hk<KM-F6S7og]l?&OWahq_Z`HTuia,!8"hj4ae0Pb
	<d7T5,L'e%f,#(>9-Ve7VnUJljG%elMYqg(Gl*Y_3Fb,Mu<R%,.kC,%i--J[85J5pt8#q]SeC\1=c"
	J_<d<Km&3XiY-bpGlZ@QgY-5DL^>2Ta28&iV">K2<M6.`X8WO6YUJrk[bE[d:FT'!BaImeO`NRhb95
	a[SZMS0UDpoNH[MeM5V]f4dq"]eCR5l/O1S*Q&+d?9aP53Uq2Bn8S,Wa,379LlKM%V(:PXQdY-pb/l
	Tk@6bJ>"A!=L$HjSC&O>*&+*1Rr#@N5#Cq]![.=2[inS<'nC.!`.KW3%(9jH/N_gLD)u(OGMN5=]&%
	MtPI`rm!,o0>SrN9(5Is58(E)fA"s&Zch=#`dY'9gGI0+>`gf;mULH"qCQVED5[B[A7R/_2MH'tZ"8
	m^`Hj2^a\%(A`V^PFWq\feK$=TOb0d)Pu_QJh4<6e@/^!-MrdI!O&3_n+,lYJ8-^pZr_[]Zd9H->,j
	@fVXEo3:>m&k2!)9B#L3f@<ONHUt<4BQ_$cjjXDk_hQE==/p_)<&;P*UJJX[MWW-KJq%Y"N-o*N_+_
	?S$=@3jjnD7UlhbB\$]*'5JM7l.'oj^3V<_Qlo>$^%\$@K%J*'!NE,+_X@(Wd'_hibNdD.^"!`:WuC
	VVH->h5>D5ZLQ.t^KtrY//!e-$'Hj^,*>E\+N^?/&rB!_P0GT*9RHRm3f_%A$k#0JQ)+mr@_2Y\=??
	_Z%:*qm+9kV5OWBiDFdK'\j?*R/50JU^]"%sHZuOW7@gp]`04"V=d;S?^^],chDqtbtX?=Ys/V'%r5
	(&]"l786E0T#7If.1rknDo@II;0)']=2Wr2`$*CL(WrG.qUD-m#S\u[!ZaY9`AVK1b^@o_VeaY?-Em
	l7.Y6Co*2WYG65FN6M\^'$cp>IBFNuXG^<U^#(fHu2&e_]A5)g*B0onTE.4A*H4LO,cckK'^:ZQE<^
	$B%?%)O[6@"pDhrq)PqYi4U?CkLC>or1jZT(i@r5-_=([LpGIkdecYsIHs3-i0G[>98)ocli!f"j7i
	c7Vo[`AVl"'L2R.EecmK_(Y&a6U'DC`-8FJ^`9mZ20o+HA=g"6`P9r*Sgc1Dcf/RnSkiM2.3,s`Te)
	<I6]aB@O[p`iOCV3(M+"'@8JYm"80gfhN*a3:<fG*dh+E5O[lW^VQX<-FYt)S%Qb%?<qfFuKiH'.Tp
	>WRGHE+D[fAh;;TgnttlD;+7r>79T@hlfMGCL>&(l&m1e9.XE*d=1`(-F:$/7tCL`K_pYR#<8LVqd&
	4k.+FOXmW+2A`@ng2e6GP0^!-uc=L=rO5G<u53q`fn?n1_Y1<4=%H-]W%bTZ+q_3e$9Z*XZN52X'jE
	7lObaG2ak'A'G/tL"PB.09sBk_;7f.D(>m#,aN]KFs9;NKH.!7,.kmWD*"b7$EW+)r8QT:<Z,9@47Q
	Z<:H496E@tW-9pCr<!l#]"*XqHdh1m\TJq<UV$#D?,,b9aA'Bb-hcG8id+hBi?hj&GK'H`+3I;qe+&
	`.e9gf6*P27BkE/X@qR?I3Y1HF]$?)g-`*nU@iq\S--sL288FD^2,*=9>P!rM!&r@5H=d2?!OXNMA>
	"PHF(0N>ZrM;;X=;f%=X5`>4?+6,[l?[X=LorfL)"F'&jGsf0]raskXR!uV5LO[k!WL5aA,*-LrX\)
	<rnFo+lhY9(m'rPh,OVqS,274$jWY0]TUq#so,)s<L]'Uq0k)mTRr!'2!h@JpnT*6V#PprY3'1P][B
	KpdpH\mdgS6=R<XTts/?rU;L*,2h@[i21X2n4XFTk-opQeMJ?2a1NRlFr^mdaUBNh2[g)a3'D:gQcg
	(hdr8S6_*dWJm1i\F@^F]\XRRA]fWA^->+*'_=Q?F^G^o[r!La8N_1R,J*mLqp3mePrit:"2qD+gXs
	9uRah#IoKBc<%W9g>M4Osrmfu?HDua-iD"q7@Nt*<l-Ck0-p*_hR0+EiCk7oDU;\k3XU'+%'AW]M/8
	s!R\(5YGR"R0!F.<g^JM-8?IM&j2$r'tm8X5LJbXk$9iSZ[O+71o?%(W#\?-Lk>n(gdBu%^3JCf6*X
	j^^r_M$[>of*e*CQK.I:?`!0e'`"r+A"*<gRn31Kp*ub$:D>#2A#+9(5!m`ThSG>,CDM5dj+`["(Fl
	_pb:N:O\[Vq>Lehpkm%9&Xd%#r=%.>rg6[2g;9H$a$CYB0-9eWhcgolBC`SO@+ca.'^4.*+1cp#+P0
	YEK:-#?+Y]Y3ec2oChp2bFb0A\O^jSdD5?[cQ^.!;]gX)s71=-?Bf9K\Y^pETS[Y@`/j5qg%i:`b;j
	g;L\m0CIcpp+hs<RXnXm,o]f5ibGNuaI`>b?C%bW>Fm-?/jEi1H$M*qZ5/BT0!8<b7=U+?q66j_;aB
	?FMnXgmg>%a?:2<>[qrfBrEfY/?IEatPp8BVu@-_=f$3SOn8-8pQ>$LR5PK"1)4!6<<I,IZ3H6?3u)
	T_]S6notui@;k"!2REc7M4<<q3OB>`e!4HT!-r6.fa$rTnR<!"%f-3-;D`5A^?lmSk)khd!FPESIFL
	4])rfJsmo*-%Q3ePb!S!<60L=\:O5hGVDfqXop1AAUps"Z=m?9S%/jA)WphIQ<u7fhbMRj1k?09<#$
	Y&P./5L(U$]e'bb\'^Soou%-A_IlXg"(\'Xb_gVWkuqAR%m?k,T5oL`/tT&<@QX`@QLXmj94McYpIS
	XDe^9FT/\l/j=h)c3*IOcV[I&7l4ocgf.<%GUC:\R>b2&)6.BgPAc4r<LO[pboeWh].,*>E\+N^?/&
	rB!_d`Q4F*!OP2O#;dp!#t>t6pXe_!>as^2TcORK;((*mpoN(o<k(W96RV^E3Q=0?onMKX>I`iZ6o,
	IlnnX-pH/FN*LL6Kf=hZ'pmkLBW9[7YmJkZ.5CDa3](Q29#`PiO^;8"ppn1[lLU@QMQn^C@o#u:Mik
	m'Ng&QAfASf^Wm/UHiRkb4"p-DW#1K.DFroJ)?"eE8qK/p,\R.JtL3,KS':]:5k8GO+`"ZCc%?h_W?
	m_P$t4P`0/kp"@ak9I</)4t[WYID+"c.n_Y+4,Jb#52CXO]st*1p$#VO5Hi#mE`dnOe:G!BjD8%n1t
	$uhr@m\7XpHEMD45l3V]@*3UkgS1<hDn_DYp#:3CLsSJ#8TB(.op@dOq:ZdlZ_n',DlbD"4M7D^J5b
	dMaY,Eb-"O[p`iOCV3(M+"'@8JYm"80gfhI\iDek8lSuq,6Hq:HAaCX2o)C;N>]eSCDSpi9DqBTH8H
	S%:m+pgmkO:%Fk%N?I#U$j#+E^i*tctL(SGU55qh]lh[.=aQn*>T6sbm7h6g(@e8_TFa[Zd+^GUqTJ
	1*BmjM10REMJLGnID\=%EHKA^6a;]`u=DRC5D3mFbi/d"clf.,hg,C%u+4#38'niQlYFkFOuo)!$=X
	fMh.#+.7AVfk!HUSg4"#/6b9o)_sK%/o2(8[X38.fa$onp<(;GR;%;e[Ti5)n#rEdj9PYmII7$l]l1
	pYa^T-9j;5T$?+9%oY.OZ\p-4>uWYND&+#NK#BT\pUrU2YpJOpa45)qS^co%#ao17_KISQQI1+juEK
	tkAQ0F'u5PXQdY-pa"b=X4W:&gUVE73[jB62HjUaqiM;q/?G&TTk(g4Sg4L-cT+f`0]jL=Rb<4]Z0%
	Vn?2oh-/0K.g;/u2]"[+FhpqBGf7>@U&Mf^%-?>:Po)-5dNA&oV'j#5'ofM((Vn0V2G5.LZ^Zmb#]m
	CCf)sfGj.$*$G_)*C^DYBFkoB*C3O3_-<'6@s9YqSgF&UtcQJK8Z9O+)(=QA@+*^CFQE<B2"%;:^D/
	/Y<p*9K_;hpL;9@_m:?WkhW-r)haTa@MWl7T/RAp+8<jKlaGasG%]2Qnsmt7hZ!(Q^k-KPq$Soh@kI
	Brj-bZsaBC$?mR<JV?.\rq7Qtj>pA;ERg)*W>K7DPbn8,nVkuC1_EtrqiWIiaf%Ii[M*km(Jjs:CX7
	+p$iQ6GnCPM@UF6m>K[,`As!,SDCoZ7(W!,#Ns!igDRV(+m])jidbUTc_(f;QMtf+V&=)@qX_f/YpC
	/4]VUt/G0%\eLJLS6hl6@=k$MXI>+h.`4p?4W331ZfOqpKA$J`^^2<$We)3ar"ig;u0E+5g^]2=J@Q
	[!okW5!'$t@As22SZ[1ae5RfjF(XCK<($*ogcJ1l$5]T@IX!lQD-8VnrUebbagF)9P\Al>airlc9Ih
	Q"A>X#>N6-=iO1Y3U,d,VUp1bj^-W_=lPp@=i&ikHUSZHY"7L03b^P3"np^?q>S4&ik#)@fDU]3f<)
	RrT8WI[ARLt=1:RFE19;pGUX6JEf;=+?)S>Jf(ECYE@"9[Z[dX;MAWh]NEf`(;I(u&`03"!@s.f)JL
	W%$bJ9"gu9O]otpR3W$^2rCq=<nN9IYB)+Z:H5R,tP<iMaSadJn2e_=P-4X><cV-q:\a)AaS2=\j#]
	3J*>UUISA@m2YB*UNiY9L=;greJ(d11ZR,>kp1],FD;+he?*Dq4quN&ddgRGe-gL80O6P@DA84qYC_
	S'(f//QRqL]mdY-.fuPIKO]b@$@:F(""<[G\gc[t%Ni'ER6P)>L1().\S'X744`/AQbk,T^^TR(%*#
	p+nN.05@`tG3MqT^Uroc:HWZ:5>_f-ma@>bd5V/5^T&BdeXJL,Eei7C%mUrdPF6PW:X9jb(ir@e)':
	N`NuuDf3E;oiMZr0fX(clt6(-,_pRf%2iV1phqJH8uD7VoD%*pDDC%,AfASr0NNc!!KQFuKKLti^q_
	LAT>TBLUYj1"@NfJHp\(3$ot9TS1HCU['Qobd9<F<8JOS4dre]*+FJ_co?[nPc=\66"gK6+RQjl`O2
	^XZ4FnZ:H5R,tP<iMaSadJg?8[80efo81WPpCma.GZSR,'\J,mK@fUDW<W#U!;6K5:O5JZp=cL0rbo
	5N7lOm"c^r8tSh=/JrX4">c4Ag`l3&;#(4LjZ^]!g)K"/S5K/HoKo9K<2($K=bl4H%'hl1tMN!CPX^
	*Xo)6\JIC8:S+:C@LISf@fpd3[L.9o[5usF9t:q:1:HX)@]h[dK>#]nj"1'gDsui^lh\b>i6bR80&=
	VVr8:`K7i0KA&&YXQ**3u/mFi/4X.q(MK(uY/!m%Ql3#=^>63aNtYR6>6qtLP@]mK;[?10fS-CZW>e
	\:NFbhGQJZ-T+`*92b=Oe!L2i2SD8-hToIjPfYj?,m!.6kT$5a:@'AT@!8dlrS;B(sL?2nN^T((?b#
	)0jL?"J@]"&Go7L=E=Ik#@%T:r95!ZiN9;IXKnREdYg7c/8Lr*c?K&A^.t%+9O\#,F-!?I$,*=9>P!
	rM!&r@6s(!i*\C1(7UUP&?&%Tp'L!.ML5o.s[ES:*`U;%ETVs8:P6?!#AW:CRdV8#!bG*qiAi)fnY[
	d'5X3l`0i<Y(I!rG9VWGF^tpX:D]+>Rk_a;gM.%e94l[MJXQ)$>-kq9f?`:TQC89QH6E_m=/5\QI>;
	cHLZ^@H[0em9E>Z4hh3N6n,*'I0IEMNX.)R4(4:V"U(X"e9NXmdXi.Ki]j=eP3`2RPD(dj(aPp6GSD
	Pr-_jS/@Z_:^'Udr;9F@%5ep=&oNZA[G3_NF$fh`rG<?K)6(?pNbTY6!Y;t\5"+A.D3Iq!R-%+$dQB
	=`j#sFj0Ld@l<WXQ?3E^6bY?oklhT8*\it<86!`s6KB#+<)"V+[_c+3n1TlKGU<(mW4M9`>^DHR_<S
	1p<HHb-4NAt9hhY(qp^[QB<eTJJ)L)rgK3E'%o5NGG!gaS.L,#Nq;Mm>l!&g^)S.#UJ;;1c17ZS)C&
	.&bCB]++C.lMAG_hpD%+]?sjL`%6:uV^_[Sk?n-B?!hlnot!o]i:5%b&Ia<Z;Y_KGgX-,mT0@9KHKa
	aE'_r]74<Np:h3o:)]li@NZ24Q4![n/*;Mp1lb/P`sYF<5prA5Sj4U6nd_[TlGVYpdlf&M\0NnACS/
	99QlnB!lb#YmX_"2<Z/OQX)?S3<a>BT)GP.<F1:rdI.dZ)J!?eEqc\Qc`^SllD[f7]&[*6i@>?@'&T
	(*18UL_[+<BH5K!hj)^-,@/]-GR&f0XE:EJ=n&G,sjJ"U\9Z!nl>VkJ(R!#*Yce>]1A%pp5^Vi$shP
	=q!n^U'uhk;4g`t]WHbgH<1?#/D%b;X>7W30c/_/oS1X'^E4]\rO,SLNUp#Kps^DRD^2le''3J*RV/
	V<_.cF#B29=*f6&cYj:fiqe&Ac(ERp<CD"f)e*\@(4A2ELu_<6,SGqH,[$@#,*=9>P!rM!&r@6s(!i
	+mib0e;4oS5qKqInRi?.=\ps^?j)_(^Qrl3jp.pYrP^KT5)s4JT6>6Qc^+k\%IPi(cE1q5Tdei3^%o
	3DkN)^16W6i6bil[$aO([66VjBCp!L,[R[aR'F1m!j3Qf5uFS%p8OOMNOhg^c-!E_2``W%]b=BJT3p
	C`Sf7*.eqi:!nc`,@sIUmUSt)g^j5,+i2a!1^hl5qJtf;R[Gtcdo=>BMacJEi3("pK',-b36N\^X0]
	<DbjX<?>!-:4grqA8`aL9s<H+g@>D;M5W<!Jk=C%A=9^A"3pkdm:9#<Ag$;`lscY-,GDcUa(eJB,<%
	6sdnof4+ctX17%-)"`shGa:%l#+YPX427QVmsGN#OnZNS_n+^/rH6a=?2pGH9\+(Be*@M>T]n1^$>C
	H*=l'*fplVJGr49$Ikf3br210':n5'(fXp^bnU%#-3USoX#$Ba*mMaSadJg?8[80efo8?sY%6m>K[[
	,RKo4TK7Jg>GKK&fB_ss5fmCH41Ygg=O).f@Bq5cGneBF)t`=K-QV)C_0PmQ6">"7P/T'S-_[,IgW7
	ROMA'pco6)12%<o6\HJ;/Q*PL)IE9ZHHXNrJ-N()H-goBi*Pf"L1N8:rML;pZ%.4@E_cutpf4&R^2E
	bF!R2eE">7;XZ:X9:3Cpu-;XVS3dfn94@K3t;'Ofdt/OmSWqiDVYUQeJ]aNb3#CcZqTjeFhCPcdd.j
	&$L)3JfF&5P>;\V`OY\J)S\dK@gCW9]sk^Of9m3Gg7:ZKDl:CP(Yd$k*Z2omb*ph8d(3?2gUBC;f;=
	Bb3HbI,/jHiTSpeKVbC8JeiV=KBK57s+=(DZYDE6c"Vd+8#c?l?HK*#QV.1=+R_;CdhcR5a5n'^knI
	eI]%rRO40LorlS%n<iNGd2>.oF:ZPPp3b;(5YGR"A'A?O[p`iOCV3(M+"'@BuMmi=Fi%B$9m&7'%iL
	[JMC:ck8f1`)-O2bV$1hdg]0I=(2_rH_*_s+poLh)G&4%k-"GqqOhqqd(LsKu^sBW:2gj14PMai3+U
	)fQBGhjt1B9L@XFR/$7;SSDAm264(9IU)l!aa93*V+2o8R\cP-1&Z?<R$\+gi`)fHHHYD*<#XG=8$?
	hZm*RO8i&.%mGe0M)r\"4kbZb&s#`H-Q;JBmlc:$^Z!G0e+MY;Z^2b0'N30q))_.$jI1@?i*jnINoF
	0$4T$"?DZGiDWeB]B7Qp9^(7o/\Ah^^)EQX>[i,`*CSB"o2@/m!;^n>Upj8[+9S2InOl#DQ:O&\gJ<
	9&7S6([:rC:<BI&^M2pLIQg_8=$\[G?lt3et%?d48!*j."I%UEd$QmX;&dIZ:H5R,tP<iMaSadJg?8
	[80efo81VDET*iD7WQgpTn5%mI1;sU5R%:V^/,XE04HD*L`/$a<$dO(2'c9XW0(+lu/3>[;k90qXQX
	'b9IBN06CsteL7-+RBTJIpB`$GZfeoV&W)qX%;D$T"6V*Q*EW<LLAAH@:Y0=^4,*'aojXW7&n;MYN+
	UjrR!_m(.-?FMJE_'%XBj5=01&cBE.'KC?WJq)Qk+MT*Chs8o;f^%TIHu:B#c/[=E/D-c"N,DtGHKo
	jGNWYk7Z5&mREA-mmK0#$@@1bNX4rnQX@a*m.S_/DU(V1[Ta#8-*Ngu<\neJ`bh.o31_54r0CE5M^a
	lIG)KF6<AqtI304I8gBZM>(IUNj3udl&'KT,W(ZY[bIVf*@X$W0aAWN15%[PBB&89N`VRM+%@aaeC=
	!M*qZ5/BT0!8<b7!Gc#9g9X:d,>GZ\r4[cW>k.b-]GODke00*=f$d:Y)4IVA&lK#D=qDgK`9\0g1"*
	QeJ'Rne3j-ZtsMI;J/^(FWm4Ua5S8:b\s*<gel/fht2Q[Z%%Q?B%,D0<Rq!s464c':qL2Ppf'dP:;5
	!IMTsGu6^Dr<`(jaSMi1A"5R%bUjUHjc<55o_?@Y](SM8@A(Eh?%SVU%!J$rE5&pO@d)V#`(qu1f=!
	BA"+/F>DOPSe;ANRlV28tXaCo`[E:unO8CqFq/_PUZT)+lK27ieY%jAEXdDhge2OJ;eiAlQ/K-M?5i
	2'NRhb]&p[Hd;TlA?YIddmF#)I3!t'dL7f(5YGR"A'A?O[p`iOCV3(M+"'@BuMmiQ*,p*RuHU[Be[d
	kK[4kk#4PlA!C"tK)]?d>26E>o7Vl!UF(A^OPK1M7=-^T;$[p[iaa;D#Ds[a>9(WW<+2]RZ?g"C!T!
	HIf9)\BK2O9iNqC**2FRR_%I0Q<Z)jI$iB[I4GCGmSZTi4<:Z/9j1j'8BrB[1mrP<go?.L9F6F`MRX
	-M?/0bj#!!d;S?^2LRjB3Q_aZVU/O#p+Rj%<V#XVi=djRiu*AO__JTu6/JJ[OGRf+R*V#'r)_a\l1L
	;^LU5tdGKM+l8<b7=U+?q66j]#-as)s=PTU9250ID_B963H-E\83ptIgCp+fpG34N,CS.X`2Lo^4o>
	9dduRlks9N-/SD3=IgN`<1I1lahQWT%8P#G]0:+IJ3?Os'$OJYNnk(?FMA%3[X<=_hC&&D4t8sMC`J
	"[M^,Un%2c*Y%o]/2QK<0Zg:WkL//fo+5aX=?=7=U<4;#7FMNf7KY"UFH'g\u:\;I*]6$3!7=RG7NH
	&-d%2*41e]jmE5G]MWqBfd7<*ei<)rQ)qOpCfg?b9RpU#LN[W'_(:B8],$@_,W&9n$X#e!Ji=MaSad
	Jg?8[80efo8?sY%6m>K[,Y\"b.uM/m9aXf),N=6<mAhH/YeO.*(;sJ>$/-mhZKo>.la7<WY]^\c/FL
	4;;-b8-K&1^Pf7CCp3=R)&ck)/P[H;nK:1rK*cK:8b;!:9lDn-!g>KBag6O:Ej&i2,Ni3ijCJf!RJ?
	XeiY6Y[%]7pLKcMu/RSPBZ>=?OH8p6d0hhNV_-eGl",/kaOMX$<\S;1d5\cBLp_[k:e:Z,3;=aaA)C
	+,J#KD_<<8ti0cmFM#<7bK*U0fiFT09^s1JKg7iACpuZ7'5JZrX-)U&+GWh=X-/t>YgaS.L,#Nq;Mm
	>l!&g^)S.#UJ;;1^(/kU\6Yp]lG=Eeh1TH$`NoSsq7Gru2is6_N'?Q*\h)Df,m]nVqJBWp<<\HF^1C
	oU^9jg<+qO=q4Z4$cK%r#NKVXi2)u*[U7Y`p-+$'kee6MN%Ble6^W[l!?>Uc!L)WGFm:7C,mM@C2T*
	C$[2OAHNK`PWF2<HHs4NHT4]_ZB%i+5Do<r#ToaNRd=k@F:Su(b;NH#.T4NLA&m[qeAj4nJ<eb+LlG
	O#%G'0k%?<!>;*K.cgu/7Pb%#L<\b"8"RBV-\?+M,$uV7/!F_i`O&NcDKYt=X4W:&gUVE73[jB6'=Z
	>,SGqH,[ni.=]Rr$_\>!K7.BRn"&(`GYYE8kkLXmm&-M3;2d_,+po\t(lM<YnrboC)FQ&.#IJbA#YX
	;P2I9FiW7ToK%[56H?D:sKsHKX\j/R?[trERspT"&(X#Bo"%lTMkA\T,n!>bW1H+<t?/%.e(/haQ:m
	7W7>q??F"f+5`-jia&JJCTb?Wf9]k;)nO=\E/\+Rq\Xr4K!"*7"s3%>rC>>WpsXlAdIfq0T\cpHW3-
	Zuq5UT5oA@s'D]kBl^g*r+EZW9h2SdctrHM@O;-uD;GVk2[fQPT<GbSh9Ei1H$M*qZ5/BT0!8<b7=U
	+?q66j]#1jg2%+X!ms:VUE;$0.UVO,i!F&Rh8Tem7HSSpY@pHVZ5b9nDpJCiN\rWij2+piQpU6h:<4
	I0dCYc@R%<l>hYd^bTUQmNip*Jl3h`_aVD#,otoLKY.ssipZU>"a)R(L!.lguiY\4#ocYm%GJ*Z(=F
	%qP-M:(lIpCS=)qO>Dd<%ocEpfntLS[\5XH61Z_8JaK%D6QkNt1Ef_lGMH64kbtf7Q'VrVNI74YQm)
	o0@1mf8Hu&_f\=.n6)!"d<4jHfSGTHSpAGKZ:H5R,tP<iMaSadJg?8[80efo8A^V;[YRelP[j$@<AZ
	!$ZL-QZFn29<jBk)7L!55EI2H9l,EH/YZ%B/>>G/aU0g**DN.!`&poI(d*eaX/ktn7]9#F":.sQpR]
	&Y(+(WX)Zf[$R;>sIesDpn<2&-%cp#>,!0rPbm`04f5FXs"a1XpS#%p:#HDfB'F0EN9A5)!qh)II&a
	YbaS!6%%]E#QV^]C*TmdQHbCqP0_&B`T(H8P)"AnR^-U@oC5oCpK7B``XGuU_$ciN,%9t]<5h?YEOZ
	RE)gX@%14)*+:bY.Ag73[jB6'=Z>,SGqH,[$@#,*=9>1*esSlmbtBGub'n9/ouj#5[@[)p!iFmC%Mq
	ote\2?bBglq7;%*S)I(JOn.GJrR(B>>h>h%6b3bs@)pLrmP>o4'&<;J2uT;M=)UF.Kp)U'4VJ1D(Mm
	!%4Kb=%H[XdYp@We#_R]ZbcdC&mD-s+)5CDYWF<+TOF_td,pR=@6GU`fYm)XV01G5)8O[p`iOCV3(M
	+"'@8JYm"80gfh`2A!KALaq$.&Q-QK_gZbEd4>b*o;SXE[me#*n[mdDEQ1=4H"7<EF-BiR2%+C5G@C
	0$MP=$#!BY'B8`qiLX+AVFbVn3b:nldlX0A!bb2MU??K\SY(qc$qV'Jdle9M?Rc/W,^*Us6@%<8@R[
	!]XB3m@R,*>E\+N^?/&rB!_Ot=a"O[t]ZM,3pubDY:EG"cE_6lpVWRJ`Pq]3&6%mY'<p'-&#_(5,lM
	mFFBgq7dAL;uHQKn1:a\7c1sNG9,(R.YkZm(Yjt.L_e5_G=Xh0lLk+%3dd@Q)b&/[YBs!fM=4rD''3
	_EJ46A1rV@N37k04@`q2O6=QpXK$C'<pMaSadJg?8[80efo8?sY%6m>K[,X1=r/B=Q&iY[.i%EdFB[
	D;QX"`.NaJ.G`Sj&F%J;f8GpiRSaL0*\cPAXh8,Y3-QM\itKEolW29(P:`toJXpa@B07KZK#9*B$4A
	lELp%CS7Dn4e"rko*VbZ^'J_;PEH_Uu82!WN^1U\kV^rI;6j]#-as)s=PT\)B//!e-$'I"(ZS(;mKZ
	*Eu7:lr&LDRj@>$4682Tp2a>qQZP)R$;;q*>,_YQf513WYh$lj2aX9q6=sH!ndbk26oN54_P2?V\<0
	E\D][c.&6(r>=`G7[ueWGDc7f73R*XkrFETbuKK>H&/%0ado_.,SDCoZ7(W!,#Nq;Mm>l!&g^)cPg?
	W:++G)p-^lL0++Pp=a2e5tCJ5TX8eHhY.iSg*f_rCA,95ac)CY.3^VK@\3"CgpWX:t2?O>KM$GSWg^
	#NKq"s"\MWB.W9g>ma]pNAU)9a7[Z6a>LBB3oVV//!e-$'Hj^,*>E\+N^?/&rB!_P2n'aAT>qEfu8[
	85Ku*FUUCJ)DT8BO>6@@D;_sWK*ZJC/>/kir<3Lli(]3,>N^J&uX&U-X]n(Hr=F7$M6b:KWm294(k:
	(U7@<sulbpWWPn!/r2UH-P10o'1jHa6=+UR'G&%o6>ZOum6;80gfhA5O,!7%sfU(1iV!,YF/O.A(1*
	`0$O["^Mqc/8A#4XV$+/]>09'$OLtoRnq3]c^m8!a^/4hbi31=IVmiZ!='<`OluQ!9E#@WQCP*!ID'
	AGU(c>B=F:q2-W4+$Sq[eT3_6B(5*2TBk#V,u8FD^2,*=9>P!rM!&r@5H=d2?!OXNNls3EebSR>clc
	i=%G!(fUS7'8jaJc
	ASCII85End
End

Function RO2Fate_Reset_SetVar()

	setdatafolder root:RO2Fate
	ControlInfo/W=RO2_Fate_Estimator list0
	
	SetVariable setvar1 disable=2
	SetVariable setvar2 disable=2
	
	switch(V_Value)
		case 0:
			SetVariable setvar1 disable=0
			break
		case 1:
			SetVariable setvar2 disable=0
			break
	endswitch

End Function

Function RO2Fate_ListBoxProc(lba) : ListBoxControl
	STRUCT WMListboxAction &lba

	Variable row = lba.row
	Variable col = lba.col
	WAVE/T/Z listWave = lba.listWave
	WAVE/Z selWave = lba.selWave

	switch( lba.eventCode )
		case -1: // control being killed
			break
		case 1: // mouse down
			break
		case 3: // double click
			break
		case 4: // cell selection
		case 5: // cell selection plus shift key
			RO2Fate_Reset_SetVar()
			break
		case 6: // begin edit
			break
		case 7: // finish edit
			break
		case 13: // checkbox clicked (Igor 6.2 or later)
			break
	endswitch

	return 0
End

Function RO2Fate_CheckProc(cba) : CheckBoxControl
	STRUCT WMCheckboxAction &cba

	switch( cba.eventCode )
		case 2: // mouse up
			Variable checked = cba.checked
			RO2Fate_AcylCheck()
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_AcylCheck()

	setdatafolder root:RO2Fate
	ControlInfo/W=RO2_Fate_Estimator check0

	switch(V_Value)
		case 0:
			Variable/G kNO2
			kNO2=0
			SetVariable setvar11 disable=2
			SetVariable setvar0 disable=2
			break
		case 1:
			SetVariable setvar11 disable=0
			SetVariable setvar0 disable=0
			break
	endswitch

End Function

Function RO2Fate_SetVarProc(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_1(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_2(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_3(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_4(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_5(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_6(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_7(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_8(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_9(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_10(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_SetVarProc_11(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			RO2Fate_FateEst()
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_1(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit?usp=sharing\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_2(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit#bookmark=id.zh9v0nmtvjrd\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_3(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit#bookmark=id.2brueyqn0sxy\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_7(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit#bookmark=id.3exx4dy1j9ty\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_8(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit#bookmark=id.b67gqgsxw8y7\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_9(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit#bookmark=id.z52tx8diithj\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_10(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit#bookmark=id.c1pweeydwi39\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_11(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit#bookmark=id.xgp0eb9v06up\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_ButtonProc_12(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			execute/Q "BrowseURL/Z \"https://docs.google.com/document/d/1roxfhBJ-ZbpacYVsWn25Xsa47DAfYU8MzmdmOeQ_67Q/edit#bookmark=id.5w7309s12316\""
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function RO2Fate_FateEst()

	setdatafolder root:RO2Fate
	
	NVAR OHRVOC,RO2,OH,HO2,NO,NO2,kHO2,kNO,kNO2,kRO2,kOH,kiso
	Make/O/N=6 RO2Fate_RelCont
	
	ControlInfo/W=RO2_Fate_Estimator list0
	
	if (V_Value==0)
		Variable bb=kHO2*HO2+kNO*NO+kOH*OH+kNO2*NO2
		RO2=(-bb+sqrt(bb^2+4*kRO2*OHRVOC*OH))/(2*kRO2)
	endif
	
	RO2Fate_RelCont[0]=kHO2*HO2
	RO2Fate_RelCont[1]=kNO*NO
	RO2Fate_RelCont[2]=kRO2*RO2
	RO2Fate_RelCont[3]=kOH*OH
	RO2Fate_RelCont[4]=kiso
	RO2Fate_RelCont[5]=kNO2*NO2
	Variable TotL=sum(RO2Fate_RelCont)
	RO2Fate_RelCont=RO2Fate_RelCont/TotL*100
	
	if (Wintype("RO2_Fate")==1)
		KillWindow RO2_Fate
	endif
	MakePieChart(RO2Fate_RelCont)

End Function

static strConstant categories="RO\B2\M+HO\B2\M;RO\B2\M+NO;RO\B2\M+RO\B2\M;RO\B2\M+OH;RO\B2\M isomerization;RO\B2\M+NO\B2\M"

Function/s MakePieChart(dataWave)
wave dataWave		// data for wedges

// these are all the inputs for generating a pie chart
	String graphName	// "" for top graph, "_new_" to create a new graph (name returned), else must be name of existing graph
	String labelsMethod	// "_wave_", "_value_", "_percent_", "_percent_and_tenths_", "_none_"

	Variable pieRadius	// 0 - 0.5
	Variable labelRadius	// 0 - 1, default is 0.7 * pieRadius
	Variable startAngleDegrees// 0, 90, 180, or 270 corresponds to Right, Bottom, Left, or Top. Default is 0 (Right)

	graphName = "RO2_Fate"
	labelsMethod = "_wave_"
	wave/t labels=  MakePieChartLabels(dataWave,categories)
	Display/W=(5,44,295,298)/N=$graphName
	graphName=PieChartForProgrammers(graphName, dataWave, labelsMethod, labels, pieRadius=0.35, labelRadius=0.4, startAngleDegrees=0)

End

static Function/wave MakePieChartLabels(data,categoryList)
wave data
string categoryList

	variable idex, num=numpnts(data), s = sum(data)
	string str, lab
	make/o/t/n=(num) labels
	for(idex=0;idex<num;idex+=1)
		sprintf str, "%2.1f", 100*data[idex]/s
		lab = stringFromList(idex, categoryList) + " " + str +"%"
		labels[idex]=lab
	endfor
	return labels
End